
/**
 *
 * @class ArtistApp
 * @author Rynelle Coronacion <dev.rynelle@gmail.com>
 */

(function() {
  window.Cms.ArtistApp = $angularModule('ArtistApp', ['ui.router', 'ng-route-api', 'content-loader', 'ui.bootstrap', 'localytics.directives', 'ngFileUpload', 'monospaced.elastic']);

}).call(this);


/**
 * Artist App
 * Artist Controller
 *
 * @class ArtistApp
 * @author Rynelle Coronacion <dev.rynelle@gmail.com>
 */

(function() {
  window.Cms.ArtistApp.controller("ArtistController", [
    '$scope', 'routeApi', '$timeout', '$window', '$modal', 'Upload', function($scope, $routeapi, $timeout, $window, $modal, $upload) {
      var ArtistController;
      ArtistController = (function() {

        /*
         * Controller Initializer
         */
        function ArtistController() {
          $scope.search = '';
          $scope.pagination = {
            total: 0,
            current: 1
          };
          $scope.cancelForm();
          $scope.getCollection();
          return;
        }


        /*
         * Get Collections
         */

        $scope.getCollection = function(page) {
          var data, url;
          $scope.loading = true;
          data = {};
          if (angular.isUndefined(page)) {
            page = $scope.pagination.current;
          }
          url = $window.Routes.GetCollection;
          url += '?search-token=' + $str_random(32);
          if (angular.isDefined(page)) {
            data.page = page;
          }
          if (angular.isDefined($scope.search)) {
            data.search = $scope.search;
          }
          $routeapi.send(url, data, 'POST').then(function(response) {
            $scope.artists = [];
            data = response.data;
            if (response.status === 200) {
              $scope.artists = data.data;
              $scope.pagination = {
                total: data.total,
                current: data.current_page,
                max: 20
              };
            }
            $scope.loading = false;
          });
        };


        /*
         * Pagination Change Page
         */

        $scope.pageChanged = function() {
          $scope.getCollection($scope.pagination.current);
        };


        /*
         * Name Slug
         */

        $scope.nameSlug = function() {
          return $scope.form.slug = $scope.form.name.toLowerCase().replace(/[^a-zA-Z0-9]+/g, '-');
        };


        /*
         * Form Edit
         */

        $scope.addEditform = function(artist) {
          var details;
          $scope.display = 'form';
          $scope.files = [];
          details = [];
          if (artist != null ? artist.description : void 0) {
            details = JSON.parse(artist.description);
          }
          if (artist != null ? artist.image : void 0) {
            $scope.files.push({
              name: artist != null ? artist.image : void 0,
              thumb: artist != null ? artist.image : void 0,
              exist: true
            });
          }
          $scope.form = {
            _id: (artist != null ? artist.id : void 0) || $str_random(12),
            name: (artist != null ? artist.name : void 0) || '',
            slug: (artist != null ? artist.slug : void 0) || '',
            details: details
          };
          $scope.details = {
            name: '',
            value: ''
          };
        };

        $scope.addMoreDetails = function() {
          var details;
          details = angular.copy($scope.details);
          if (details.name.length > 0 && details.value.length > 0) {
            $scope.form.details.push(details);
            $scope.details.name = '';
            $scope.details.value = '';
          }
        };

        $scope.deleteDetail = function(index) {
          return $scope.form.details.splice(index, 1);
        };


        /*
         * Cancel/Reset Form or other variables
         */

        $scope.cancelForm = function() {
          $scope.display = 'lists';
          $scope.error = {};
          $scope.form = {};
          $scope.onsuccess = false;
          $scope.onsubmit = false;
          $scope.onmessage = '';
          $scope.modalartist = {};
        };


        /**
         *
         * @return submit
         */

        $scope.submit = function() {
          var data;
          $scope.onsubmit = true;
          data = $scope.form;
          data.file = _.last($scope.files);
          $upload.upload({
            url: $window.Routes.SubmitForm,
            data: data
          }).then(function(response) {
            var _data;
            _data = response.data;
            $scope.error = {};
            if (response.status === 200) {
              if (_data != null ? _data.errors : void 0) {
                $scope.onsubmit = false;
                return $scope.error = _data.errors;
              } else {
                $scope.onsuccess = true;
                $scope.onmessage = _data;
                return $timeout(function() {
                  $scope.cancelForm();
                  return $scope.getCollection();
                }, 2000);
              }
            }
          }, null, function(evt) {
            var progressPercentage, ref;
            progressPercentage = parseInt(100.0 * evt.loaded / evt.total);
            if ((ref = evt.config._file) != null) {
              ref.progress = progressPercentage;
            }
          });
        };


        /*
         * Close Modal
         */

        $scope.closeModal = function() {
          if ($scope.modalInstance) {
            return $scope.modalInstance.dismiss("cancel");
          }
        };


        /*
         * Delete Collection Modal
         */

        $scope["delete"] = function(artist) {
          $scope.modalartist = artist;
          $scope.onsubmitdelete = false;
          $scope.modalInstance = $modal.open({
            templateUrl: "MODAL_DELETE_ARTIST",
            size: 'md',
            scope: $scope,
            backdrop: 'static',
            keyboard: false
          });
        };


        /*
         * Confirm Delete
         */

        $scope.deleteConfirm = function() {
          var data, url;
          $scope.onsubmitdelete = true;
          url = $window.Routes.DeleteArtist;
          data = {
            _id: $scope.modalartist.id
          };
          $routeapi.send(url, data, 'POST').then(function(response) {
            $scope.closeModal();
            $scope.cancelForm();
            return $scope.getCollection();
          });
        };

        return ArtistController;

      })();
      return new ArtistController();
    }
  ]);

}).call(this);
