
/**
 *
 * @class SongApp
 * @author Rynelle Coronacion <dev.rynelle@gmail.com>
 */

(function() {
  window.Cms.SongApp = $angularModule('SongApp', ['ui.router', 'ng-route-api', 'ng-filter', 'content-loader', 'ui.bootstrap', 'localytics.directives', 'monospaced.elastic']);

}).call(this);


/**
 * Song App
 * Song Controller
 *
 * @class SongApp
 * @author Rynelle Coronacion <dev.rynelle@gmail.com>
 */

(function() {
  window.Cms.SongApp.controller("SongController", [
    '$scope', 'routeApi', '$timeout', '$window', '$modal', function($scope, $routeapi, $timeout, $window, $modal) {
      var SongController;
      SongController = (function() {

        /*
         * Controller Initializer
         */
        function SongController() {
          var c, capo, caponame, i;
          $scope.search = '';
          $scope.scrapsearch = '';
          $scope.pagination = {
            total: 0,
            current: 1
          };
          $scope.types = $window.Vars.Types;
          $scope.capos = [];
          for (c = i = 0; i <= 12; c = i += 1) {
            if (c === 0) {
              caponame = 'No Capo';
            } else if (c === 1) {
              caponame = '1st fret';
            } else if (c === 2) {
              caponame = '2nd fret';
            } else if (c === 3) {
              caponame = '3rd fret';
            } else {
              caponame = c + 'th fret';
            }
            capo = {
              id: c,
              name: caponame
            };
            $scope.capos.push(capo);
          }
          $scope.difficulties = [
            {
              id: 1,
              name: 'Novice'
            }, {
              id: 2,
              name: 'Intermediate'
            }, {
              id: 3,
              name: 'Advanced'
            }
          ];
          $scope.cancelForm();
          $scope.getArtists();
          $scope.getCollection();
          $scope.multiScraper();
          return;
        }


        /*
         * Get Collections
         */

        $scope.getArtists = function() {
          var url;
          $scope.artists = [];
          url = $window.Routes.Artists;
          url += '?search-token=' + $str_random(32);
          $routeapi.send(url, {}, 'POST').then(function(response) {
            return $scope.artists = response.data;
          });
        };


        /*
         * Get Collections
         */

        $scope.getCollection = function(page) {
          var data, url;
          $scope.loading = true;
          data = {};
          if (angular.isUndefined(page)) {
            page = $scope.pagination.current;
          }
          url = $window.Routes.GetCollection;
          url += '?search-token=' + $str_random(32);
          if (angular.isDefined(page)) {
            data.page = page;
          }
          if (angular.isDefined($scope.search)) {
            data.search = $scope.search;
          }
          $routeapi.send(url, data, 'POST').then(function(response) {
            $scope.songs = [];
            data = response.data;
            if (response.status === 200) {
              $scope.songs = data.data;
              $scope.pagination = {
                total: data.total,
                current: data.current_page,
                max: 20
              };
            }
            $scope.loading = false;
          });
        };


        /*
         * Pagination Change Page
         */

        $scope.pageChanged = function() {
          $scope.getCollection($scope.pagination.current);
        };


        /*
         * Name Slug
         */

        $scope.titleSlug = function() {
          return $scope.form.slug = $scope.form.title.toLowerCase().replace(/[^a-zA-Z0-9]+/g, '-');
        };


        /*
         * Form Edit
         */

        $scope.addEditform = function(song, is_scrap) {
          var ref, type;
          if (is_scrap == null) {
            is_scrap = false;
          }
          $scope.display = 'form';
          $scope.is_edit = angular.isDefined(song);
          $scope.song = song;
          if (is_scrap === true && (song != null ? song.type : void 0)) {
            type = _.findWhere($scope.types, {
              slug: song.type
            });
          } else {
            type = song != null ? song.type : void 0;
          }
          $scope.form = {
            _id: (song != null ? song.id : void 0) || $str_random(12),
            title: (song != null ? song.title : void 0) || '',
            slug: (song != null ? song.slug : void 0) || '',
            artist: (song != null ? (ref = song.artist) != null ? ref._id : void 0 : void 0) || $str_random(12),
            artist_other: (song != null ? song.artist_other : void 0) || '',
            chords: (song != null ? song.chords : void 0) || "[Intro]",
            capo: (song != null ? song.capo : void 0) || 0,
            version: (song != null ? song.version : void 0) || '1',
            type: (type != null ? type._id : void 0) || 1,
            difficulty: (song != null ? song.difficulty : void 0) || 1,
            audio: (song != null ? song.audio : void 0) || '',
            video: (song != null ? song.video : void 0) || ''
          };
        };


        /*
         * Cancel/Reset Form or other variables
         */

        $scope.cancelForm = function() {
          $scope.display = 'lists';
          $scope.error = {};
          $scope.form = {};
          $scope.onsuccess = false;
          $scope.onsubmit = false;
          $scope.onmessage = '';
          $scope.modalsong = {};
        };


        /**
         *
         * @return submit
         */

        $scope.submit = function() {
          var data, url;
          data = $scope.form;
          url = $window.Routes.SubmitForm;
          $scope.onsubmit = true;
          $routeapi.send(url, data, 'POST').then(function(response) {
            var _data;
            _data = response.data;
            $scope.onsubmit = false;
            $scope.error = {};
            if (response.status === 200) {
              if (_data != null ? _data.errors : void 0) {
                $scope.onsubmit = false;
                $scope.error = _data.errors;
              } else {
                $scope.onsuccess = true;
                $scope.onmessage = _data;
                $scope.getArtists();
                $timeout(function() {
                  $scope.cancelForm();
                  return $scope.getCollection();
                }, 2000);
              }
            }
          });
        };


        /*
         * Close Modal
         */

        $scope.closeModal = function() {
          if ($scope.modalInstance) {
            return $scope.modalInstance.dismiss("cancel");
          }
        };


        /*
         * Delete Collection Modal
         */

        $scope["delete"] = function(song) {
          $scope.modalsong = song;
          $scope.onsubmitdelete = false;
          $scope.modalInstance = $modal.open({
            templateUrl: "MODAL_DELETE_SONG",
            size: 'md',
            scope: $scope,
            backdrop: 'static',
            keyboard: false
          });
        };


        /*
         * Scrap Modal
         */

        $scope.scriper = function() {
          $scope.formscrap = {};
          $scope.modalInstance = $modal.open({
            templateUrl: "MODAL_SCRAPER",
            size: 'md',
            scope: $scope,
            backdrop: 'static',
            keyboard: false
          });
        };


        /*
         * Scrap Confirm
         */

        $scope.scrapConfirm = function(autoedit) {
          var data, url;
          if (autoedit == null) {
            autoedit = false;
          }
          $scope.onscrap = true;
          $scope.formscrap.error = null;
          $scope.formscrap.done = false;
          $scope.formscrap.autoedit = autoedit;
          $scope.formscrap.chords = [];
          $scope.formscrap.form = {};
          url = $window.Routes.ScrapUrl;
          data = {
            _id: $str_random(32),
            url: $scope.formscrap.url
          };
          $routeapi.send(url, data, 'POST').then(function(response) {
            var _data, ref, ref1;
            _data = response.data;
            if (response.status === 200) {
              if (_data != null ? _data.errors : void 0) {
                $timeout(function() {
                  var ref;
                  return $scope.formscrap.error = (ref = _data.errors) != null ? ref.url : void 0;
                });
              } else {
                $scope.formscrap.form = _data.form;
                if (((ref = $scope.formscrap.form.artist) != null ? ref._id : void 0) === 'others') {
                  $scope.formscrap.form.artist_other = (ref1 = $scope.formscrap.form.artist) != null ? ref1.name : void 0;
                }
                $scope.formscrap.chords = _data.chords;
                $scope.formscrap.done = true;
                if (autoedit === true) {
                  $scope.scrapContinue();
                }
                $scope.formscrap.autoedit = false;
              }
            }
            return $scope.onscrap = false;
          })["catch"](function(reason) {
            $scope.formscrap.error = 'Connection timed out. Please try again in a few seconds.';
            return $scope.onscrap = false;
          });
        };


        /*
         * Edit Scrap
         */

        $scope.scrapContinue = function() {
          var form;
          form = $scope.formscrap.form;
          if (form) {
            $scope.addEditform(form, true);
            $scope.formscrap = {};
            $scope.closeModal();
            $scope.is_edit = false;
          }
        };


        /*
         * Confirm Delete
         */

        $scope.deleteConfirm = function() {
          var data, url;
          $scope.onsubmitdelete = true;
          url = $window.Routes.DeleteSong;
          data = {
            _id: $scope.modalsong.id
          };
          $routeapi.send(url, data, 'POST').then(function(response) {
            $scope.closeModal();
            $scope.cancelForm();
            return $scope.getCollection();
          });
        };


        /*
         * Multi Scraper
         */

        $scope.multiScraper = function() {
          $scope.scrapsongs = {};
          return $scope.scrappaging = {
            count: 0,
            current: 1,
            total: 0
          };
        };

        $scope.saveFormScraper = function(song, currentpage) {
          var data, url;
          song.onrequest = true;
          url = $window.Routes.ScrapUrl;
          data = {
            _id: song._id,
            page: currentpage,
            url: song.href,
            autosave: 'save'
          };
          $routeapi.send(url, data, 'POST').then(function(response) {
            data = response.data;
            song = _.findWhere($scope.scrapsongs[data.page], {
              _id: data._id
            });
            if (song) {
              song.exists = true;
            }
            return song.onrequest = false;
          })["catch"](function(reason) {
            return song.onrequest = false;
          });
        };

        $scope.editFormScraper = function(song) {
          $scope.addEditform();
          $scope.scriper();
          $scope.formscrap.url = song.href;
          $scope.scrapConfirm(true);
        };

        $scope.getMultiScrap = function(page, reset) {
          var data, url;
          if (reset == null) {
            reset = false;
          }
          if ($scope.scrapsongs[page] && reset === false) {
            $scope.scrappaging.current = page;
            $scope.scrappaging.total = 0;
          } else {
            $scope.loading = true;
            url = $window.Routes.GetMultiScrap;
            url += '?search-token=' + $str_random(32);
            data = {};
            if (angular.isDefined(page)) {
              data.page = page;
            }
            if (angular.isDefined($scope.scrapsearch)) {
              data.search = $scope.scrapsearch;
            }
            $routeapi.send(url, data, 'POST').then(function(response) {
              var songsize;
              data = response.data;
              if (response.status === 200) {
                $scope.scrapsongs[data.page] = data.data;
                if (parseInt(data.page) === 1) {
                  $scope.scrappaging.count = data.paging;
                }
                $scope.scrappaging.current = data.page;
                if (data.page > 1) {
                  songsize = _.size($scope.scrapsongs[data.page]);
                  $scope.scrappaging.total = (songsize * data.page) - songsize;
                }
              }
              $scope.loading = false;
            });
          }
        };

        return SongController;

      })();
      return new SongController();
    }
  ]);

}).call(this);
