
/**
 * systemFilter
 *
 * @class systemFilter
 * @package AngularModules
 * @author Anthony Pillos <dev.anthonypillos@gmail.com>
 */

(function() {
  angular.module('ng-filter', []).filter('th', function() {
    return function(number) {
      if (number === 1) {
        return number + "st";
      }
      if (number === 2) {
        return number + "nd";
      }
      if (number === 3) {
        return number + "rd";
      }
      return number + "th";
    };
  }).filter('isEmpty', function() {
    return function(object) {
      return angular.equals({}, object);
    };
  }).filter('groupBy', [
    '$parse', function($parse) {
      return _.memoize(function(items, field) {
        var getter;
        getter = $parse(field);
        return _.groupBy(items, function(item) {
          return getter(item);
        });
      });
    }
  ]).filter('multipleOf', function() {
    return function(arrayLength) {
      var arr, i;
      arrayLength = Math.ceil(arrayLength);
      arr = new Array(arrayLength);
      i = 0;
      while (i < arrayLength) {
        arr[i] = i;
        i++;
      }
      return arr;
    };
  }).filter('format_bytes', function() {
    return function(bytes, si) {
      var thresh, u, units;
      si = 1024;
      thresh = si ? 1000 : 1024;
      if (bytes < thresh) {
        return bytes + ' B';
      }
      units = si ? ['KB', 'MB', 'GB', 'TB', 'PB', 'EB', 'ZB', 'YB'] : ['KiB', 'MiB', 'GiB', 'TiB', 'PiB', 'EiB', 'ZiB', 'YiB'];
      u = -1;
      while (true) {
        bytes /= thresh;
        ++u;
        if (!(bytes >= thresh)) {
          break;
        }
      }
      return bytes.toFixed(1) + ' ' + units[u];
    };
  }).filter('str_limit', function() {
    return function(value, max, wordwise, tail) {
      var lastspace;
      if (!value) {
        return '';
      }
      max = parseInt(max, 10);
      if (!max) {
        return value;
      }
      if (value.length <= max) {
        return value;
      }
      value = value.substr(0, max);
      if (wordwise) {
        lastspace = value.lastIndexOf(' ');
        if (lastspace !== -1) {
          value = value.substr(0, lastspace);
        }
      }
      return value + (tail || '...');
    };
  }).filter('truncateMiddle', function() {
    return function(str, length, separator) {
      var end, pad, start;
      if (length == null) {
        length = 20;
      }
      if (separator == null) {
        separator = '...';
      }
      if (str === null) {
        return '';
      }
      if (str === void 0) {
        return '';
      }
      if (str.length <= length) {
        return str;
      }
      pad = Math.round((length - separator.length) / 2);
      start = str.substr(0, pad);
      end = str.substr(str.length - pad);
      return [start, separator, end].join('');
    };
  }).filter('mobile', function() {
    return function(str) {
      var city, country, mobile, number, value;
      value = str.toString().trim().replace(/^\+|\s/g, '');
      country = value.slice(0, 3);
      city = value.slice(3, 5);
      number = value.slice(5);
      number = number.slice(0, 3) + ' ' + number.slice(3);
      mobile = (country + ' ' + city + ' ' + number).trim();
      mobile = mobile !== '' ? '+' + mobile : void 0;
      return mobile;
    };
  }).filter('landline', function() {
    return function(str) {
      var city, country, number, value;
      value = str.toString().trim().replace(/^\+|\s/g, '');
      country = value.slice(0, 3);
      city = value.slice(3, 4);
      number = value.slice(4);
      number = number.slice(0, 3) + ' ' + number.slice(3);
      return ('+' + country + ' ' + city + ' ' + number).trim();
    };
  }).filter('priceCurrency', [
    '$window', function($window) {
      return function(str, currency) {
        var ref;
        if (!str) {
          str = 0;
        }
        if (angular.isUndefined(currency)) {
          currency = $window.PrintArabia.Vars.Currency || '$';
        }
        if ((((ref = $window.Vars) != null ? ref.CurrencyPosition : void 0) != null) && $window.Vars.CurrencyPosition === true) {
          return String(currency + str);
        }
        return str + String(currency);
      };
    }
  ]).filter('mmToCm', function() {
    return function(mm, decimalPoint) {
      var remainder, x, y;
      x = 0;
      if (angular.isUndefined(decimalPoint)) {
        decimalPoint = 2;
      }
      if (_.isNumber(mm)) {
        x = _h.numberFormat(mm * 0.1, decimalPoint);
        remainder = x % 1;
        if (remainder === 0) {
          x = Math.ceil(x);
        } else {
          y = x.toString().substr(-1, 1);
          if (y === "0") {
            x = x.toString().substring(0, x.toString().length - 1);
          }
        }
      }
      return x;
    };
  }).filter('trusted_html', [
    '$sce', function($sce) {
      return function(text) {
        return $sce.trustAsHtml(text);
      };
    }
  ]).filter('toDateFormat', function() {
    return function(dateString, format) {
      if (angular.isUndefined(format)) {
        format = 'YYYY-MM-DD HH:mm:ss';
      }
      return moment(dateString).format(format);
    };
  }).filter('dateTimeFormat', [
    '$filter', function($filter) {
      return function(dateString, format) {
        var a;
        if (angular.isUndefined(format)) {
          format = 'YYYY-MM-DD';
        }
        a = dateString.split(/[^0-9]/);
        return $filter('date')(new Date(a[0], a[1] - 1, a[2], a[3], a[4], a[5]), format);
      };
    }
  ]).filter('difficulty', [
    function() {
      return function(num) {
        var diff, label;
        diff = parseInt(num);
        label = 'Novice';
        if (diff === 2) {
          label = 'Intermediate';
        } else if (diff === 3) {
          label = 'Advanced';
        }
        return label;
      };
    }
  ]);

}).call(this);


/**
 * Route Factory
 *
 * @class Api Factory
 */

(function() {
  angular.module('ng-route-api', []).factory("routeApi", [
    '$http', '$rootScope', '$q', '$window', function($http, $rootScope, $q, $window) {
      return {
        send: function(url, data, method, qdefer, isajax) {
          var httpDataRequest;
          if (data == null) {
            data = {};
          }
          if (method == null) {
            method = 'GET';
          }
          if (isajax === true) {
            this.$$additionalHTTPHeader();
          }
          data._token = $window.csrf;
          httpDataRequest = {
            method: method,
            url: url,
            headers: {
              'Content-Type': 'application/x-www-form-urlencoded; charset=UTF-8'
            },
            data: $.param(data)
          };
          if (qdefer) {
            return this.$$qDeferRequest(httpDataRequest, qdefer);
          }
          if (method === 'GET') {
            return $http.get(url);
          }
          return $http(httpDataRequest);
        },

        /*
        			 *   Authentication   = Site Authentication Token
        			 *   X-Requested-With = Set Http Request to AJAX FORMAT
         */
        $$additionalHTTPHeader: function() {
          var AuthKey;
          if (!AuthKey) {
            AuthKey = $str_random();
          }
          $http.defaults.headers.common['Authentication'] = AuthKey || null;
          $http.defaults.headers.common['X-Requested-With'] = "XMLHttpRequest";
        },
        $$qDeferRequest: function(httpDataRequest, qdefer) {
          var promise;
          if (angular.isUndefined(this.qRequest)) {
            this.qRequest = [];
          }
          this.qRequest.push(qdefer);
          promise = $http(angular.extend(httpDataRequest, {
            timeout: qdefer.promise
          }));
          promise["finally"]((function() {
            this.qRequest = _.filter(this.qRequest, function(request) {
              return request.url !== httpDataRequest.url;
            });
          }));
          return promise;
        },
        cancel: function() {
          angular.forEach(this.qRequest, function(canceller) {
            canceller.resolve();
          });
          if (angular.isUndefined(this.qRequest)) {
            return this.qRequest = [];
          }
        }
      };
    }
  ]);

}).call(this);


/**
 * iCheckDirective
 * @class Directive
 */

(function() {
  angular.module('allow-pattern', []).directive("allowPattern", function() {
    return {
      restrict: "A",
      compile: function(tElement, tAttrs) {
        return function(scope, element, attrs) {
          element.bind('keypress', function(event) {
            var _alpha, _decimal, _number, allow_pattern, keyCode, keyCodeChar;
            _number = angular.isDefined(attrs.number) ? '[0-9]' : null;
            _decimal = angular.isDefined(attrs.decimal) ? '[.]' : null;
            _alpha = angular.isDefined(attrs.alpha) ? '[a-z]' : null;
            allow_pattern = attrs.allowPattern;
            if (allow_pattern.length === 0) {
              allow_pattern = '';
              if (angular.isDefined(attrs.number)) {
                allow_pattern += '|[0-9]';
              }
              if (angular.isDefined(attrs.decimal)) {
                allow_pattern += '|[.]';
              }
              if (angular.isDefined(attrs.alpha)) {
                allow_pattern += '|[a-z]';
              }
              if (angular.isDefined(attrs.allow)) {
                allow_pattern += '|[' + attrs.allow + ']';
              }
              allow_pattern = allow_pattern.slice(1);
            }
            keyCode = event.which || event.keyCode;
            keyCodeChar = String.fromCharCode(keyCode);
            if (!keyCodeChar.match(new RegExp(allow_pattern, 'i'))) {
              event.preventDefault();
              return false;
            }
          });
        };
      }
    };
  });

}).call(this);


/**
 * iCheckDirective
 * @class Directive
 */

(function() {
  angular.module('content-loader', []).directive("contentLoader", [
    function($rootScope) {
      return {
        restrict: "A",
        link: function($scope, $element, $attrs) {
          var _template, attr_id;
          attr_id = $attrs.contentLoader;
          _template = "<div class=\"content-loader\" id=\"__" + attr_id + "\">\n    <div class=\"content-loader-block\"></div>\n    <div class=\"content-loader-spinner\">\n        <i class=\"fa fa-spinner fa-spin\"></i>\n        <div>Please wait...</div>\n    </div>\n</div>";
          $element.css('position', 'relative');
          $element.append(_template);
          $scope.$watch(attr_id, function(isShow) {
            var _el;
            _el = angular.element('#__' + attr_id);
            if (isShow === false) {
              return _el.fadeOut();
            } else {
              return _el.show();
            }
          });
        }
      };
    }
  ]);

}).call(this);


/**
 * iCheckDirective
 * @class Directive
 */

(function() {
  angular.module('icheck', []).directive('icheck', [
    '$timeout', function($timeout) {
      return {
        restrict: "A",
        require: 'ngModel',
        link: function($scope, element, $attrs, ngModel) {
          return $timeout(function() {
            var $element, value;
            value = $attrs.value;
            $element = $(element);
            $element.iCheck({
              checkboxClass: 'icheckbox_square-blue',
              radioClass: 'iradio_square-blue',
              increaseArea: '20%'
            });
            $scope.$watch($attrs.ngModel, function(newValue) {
              return $element.iCheck('update');
            });
            return;
            $element.on('ifChanged', function(event) {
              if ($element.attr('type') === 'radio' && $attrs.ngModel) {
                $scope.$apply(function() {
                  ngModel.$setViewValue(value);
                });
              }
            });
          });
        }
      };
    }
  ]);

}).call(this);


/**
 * Enable multi-select for select option using bootstrap multiselect.
 * multi-select-directive
 *
 * @class MultiSelectDirective Directives
 * @package AngularModules
 * @author Anthony Pillos <dev.anthonypillos@gmail.com>
 */

(function() {
  angular.module('MultiSelectDirective', []).directive("multiSelectDirective", [
    '$rootScope', '$timeout', function($rootScope, $timeout) {
      return {
        restrict: "A",
        scope: {
          listenOnChange: "@"
        },
        link: function(scope, element, attrs) {
          var params;
          params = {
            nonSelectedText: attrs.msSelectedText || 'Please Select Options',
            includeSelectAllOption: attrs.msShowSelectAll || false,
            enableFiltering: attrs.enableSearch || true,
            buttonWidth: '100%',
            maxHeight: attrs.msHeight,
            templates: {
              filter: "<li class=\"multiselect-item filter\"><div class=\"input-group\"><input class=\"form-control multiselect-search\" type=\"text\"></div></li>",
              li: "<li><a><label class=\"form-checkbox form-normal form-primary form-text\"></label></a></li>"
            },
            onChange: function(element, checked, select) {
              var findById;
              findById = $(element).val();
              return $rootScope.$emit(scope.listenOnChange, findById, checked);
            }
          };
          return $timeout(function() {
            return element.multiselect(params);
          });
        }
      };
    }
  ]);

}).call(this);
