<?php

namespace Cms\Chords;

/**
 * ArtistController
 *
 * @package RynelleCMS
 * @author  Rynelle Coronacion <dev.rynelle@gmail.com>
 * @version v1
 */

use Cms\CmsBaseController;

use Input;
use Libraries\Validator\Rules;

use Repositories\Chords\ArtistRepository;

class ArtistController extends CmsBaseController {


	/**
	 * Set Global View Path for Settings
	 */
	protected $view_path = 'chords.artists';

	/**
	 * Repositories\Chords\ArtistRepository;
	 */
	protected $_artist;

	/**
	 * Controller Initializer
	 *
	 * @return void
	 */
	public function __construct(ArtistRepository $_artist)
	{
		$this->_artist = $_artist;
	}

	/**
	 * Display Index Page
	 *
	 * @return void
	 */
	public function getIndex()
	{
		$data = [];
		return $this->view('index', $data);
	}

	/**
	 * Get Collections
	 *
	 * @return void
	 */
	public function postCollection()
	{
		
		$input 	 = Input::all();

		$artists = $this->_artist->collections($input);
        $data  	 = [];
        foreach ($artists as $artist)
        {
            $data[] =  [
                            'id'     	  => encrypt($artist->id),
                            'name'        => $artist->name,
                            'slug'  	  => $artist->slug,
                            'description' => $artist->description,
                            'image' 	  => $artist->image,
                        ];
        }

        $artists->setItems( $data );

		return $this->response($artists);

	}


	/**
	 * Form Update
	 *
	 * @return void
	 */
	public function postSubmit()
	{
		$input = Input::all();

		if ( $input ) {

			$id  	     = decrypt($input['_id']);
			$message     = 'New Artist Successfully Created.';
			$file        = @$input['file'];
			$externalurl = @$input['url'];

            $rules = [
                        'name' 		  => 'required',
                        'slug'  	  => 'required|unique:artists,slug,NULL,NULL,deleted_at,NULL'
                     ];
            if ( $id ) {
            	$rules['slug'] = 'required';
            	$message 	   = 'Artist Successfully Updated.';
            }

			$validate = Rules::validate($input, $rules);

			if ( $validate )
				return $this->response($validate);

			if ( $file && !is_array($file) ) {
				$artist_storage  = storage_path('artists');
				$uploadfile	     = uploadSave($file, $artist_storage);
				$input['avatar'] = $uploadfile['path'];
			}
			elseif ( $externalurl ) {
				$input['avatar'] = $externalurl;
			}

			$details = @$input['details'] ?: [];
			$input['description'] = json_encode($details);

			$artist = $this->_artist->save($input, $id);

			return $this->response($message);

		}
	}


    /**
    * Delete Artist
    * Set deleted_at as deleted
    *
    * @return void
    * @access private
    **/
    public function postDeleteArtist()
    {

		$input = Input::all();

		if ( $input ) {
			$id  = decrypt($input['_id']);
			$this->_artist->delete($id);
		}

		return $this->response(true);

    }

}