<?php

namespace Cms;

/**
 * CmsBaseController
 *
 * @package RynelleCMS
 * @author  Rynelle Coronacion <dev.rynelle@gmail.com>
 * @version v1
 */

use Response;
use Controller;
use Session;
use Illuminate\Support\Facades\View;

use Traits\Logger;

class CmsBaseController extends Controller {

	use Logger;
	
	const CMS_PAGES = 'cms.pages.';

	/**
	 * Setup the layout used by the controller.
	 *
	 * @return void
	 */
	protected function view($view, $data = [])
	{
		$make_view = self::CMS_PAGES;

		if ( @$this->view_path )
		{
			$make_view .= str_finish(@$this->view_path, '.');
		}
		$data['view_path'] = $make_view;

		return View::make( $make_view . $view )->with($data);
	}

	/**
	 * Setup the layout used by the controller.
	 *
	 * @return void
	 */
	protected function logs( $message, $type = 'info' )
	{
        $this->log(__METHOD__, $type)->message("[BACKEND] " . $message);
	}

	/**
	 * Setup the layout used by the controller.
	 *
	 * @return void
	 */
	protected function response( $data, $code = 200 )
	{
        return Response::json( $data, $code );
	}


	/**
	 * Get Logged User
	 *
	 * @return void
	 */
	protected function currentUser($field = null, $decrypt = true)
	{
		$user = Session::get(SESSION_CMS_USERINFO);

		if ( $field === null )
		{
			return $user;
		}
		
		$logged = $user[$field];

		if ( $field == 'id' && $decrypt === true )
		{
			return decrypt($logged);
		}

		return $logged;

	}

}
