<?php

namespace Cms\Settings;

/**
 * SettingController
 *
 * @package RynelleCMS
 * @author  Rynelle Coronacion <dev.rynelle@gmail.com>
 * @version v1
 */

use Cms\CmsBaseController;

use Input;
use Redirect;
use Repositories\System\SettingRepository;

class SettingController extends CmsBaseController {


	/**
	 * Set Global View Path for Settings
	 */
	protected $view_path = 'settings';

	/**
	 * Repositories\System\SettingRepository;
	 */
	protected $_setting;

	/**
	 * Setup the layout used by the controller.
	 *
	 * @return void
	 */
	public function __construct(SettingRepository $_setting)
	{
		$this->_setting = $_setting;
	}

	/**
	 * Setup the layout used by the controller.
	 *
	 * @return void
	 */
	public function getIndex()
	{
		return Redirect::route(ROUTE_CMS_SETTING_GENERALS);
	}

	/**
	 * General Settings
	 *
	 * @return void
	 */
	public function getGeneral()
	{
		$data = [
					'title'    => 'General Settings',
					'label'	   => 'Site Details',
					'pageload' => 'general'
				];
		return $this->view('index', $data);
	}

	/**
	 * Social Settings
	 *
	 * @return void
	 */
	public function getSocial()
	{
		$data = [
					'title'    => 'Social Network Link',
					'label'	   => 'Social Networking Sites',
					'pageload' => 'social'
				];
		return $this->view('index', $data);
	}

	/**
	 * Comments Settings
	 *
	 * @return void
	 */
	public function getCommentPlugins()
	{
		$data = [
					'title'    => 'Comment Plugins',
					'label'	   => 'Comment System [ Disqud | Facebook ]',
					'pageload' => 'comment'
				];
		return $this->view('index', $data);
	}

	/**
	 * Google Analytics Settings
	 *
	 * @return void
	 */
	public function getGoogleAnalytics()
	{
		$data = [
					'title'    => 'Google Analytics',
					'label'	   => 'Google Analytics Solutions',
					'pageload' => 'analytics'
				];
		return $this->view('index', $data);
	}

	/**
	 * Get Details
	 *
	 * @return void
	 */
	public function postDetails()
	{
		
		$input = Input::all();

		if ( $input ) {
			$type = $input['type'];

			$settings = $this->_setting->getsetting($type, 'type', false);

			$response = array_map(function($res) {
				return [
							'id'    => encrypt($res['id']),
							'type'  => $res['type'],
							'code'  => $res['code'],
							'label' => $res['label'],
							'value' => $res['value'],
					   ];
			}, $settings->toArray());
			
			return $this->response($response);
		}

	}

	/**
	 * Save Settings
	 *
	 * @return void
	 */
	public function postUpdate()
	{
		
		$input = Input::all();

		if ( $input ) {

			$forms = $input['forms'];

			if ( $forms ) {
				foreach ($forms as $form) {
					$id   = decrypt($form['id']);
					$data = [ 'value' => $form['value']];
					$this->_setting->save($data, $id);
				}
			}

			return $this->response(true);

		}

	}
}