<?php

namespace Cms\User;

/**
 * ProfileController
 *
 * @package RynelleCMS
 * @author  Rynelle Coronacion <dev.rynelle@gmail.com>
 * @version v1
 */

use Cms\CmsBaseController;

use Input;
use Redirect;

use Libraries\Validator\Rules;
use Repositories\Users\UserRepository;

class ProfileController extends CmsBaseController {

	/*
	 * Repositories\Users\UserRepository
	 */
	private $_user;

    /**
    * __construct()
    * Initialize our Class Here for Dependecy Injection
    *
    * @return void
    * @access  public
    **/
    public function __construct(
    								UserRepository $_user
    						   )
    {
        $this->_user = $_user;
    }

	/**
	 * Index Page
	 *
	 * @return void
	 */
	public function getIndex()
	{
		return $this->view('profile.index');
	}

	/**
	 * Get Information
	 *
	 * @return void
	 */
	public function postInformation()
	{
		$input = Input::all();
		if ( $input ) {
			$id   = decrypt($input['_id']);
			$user = $this->_user->get($id); 

			$response = [
							'id'         => $input['_id'],
							'email'      => $user->email,
							'username'   => $user->username,
							'first_name' => $user->first_name,
							'last_name'  => $user->last_name,
						];
			return $this->response($response);
		}
	}

	/**
	 * Form Update
	 *
	 * @return void
	 */
	public function postUpdate()
	{
		$input = Input::all();
		if ( $input ) {
			$id  = decrypt($input['_id']);
			unset($input['_id']);
			unset($input['_token']);

            $rules = [
                        'first_name' => 'required',
                        'last_name'  => 'required',
                        'username'   => 'required',
                        'email'   	 => 'required|email',
                     ];

            if ( @$input['password'] ) {
            	$rules['password']  			= 'confirmed';
            	$rules['password_confirmation'] = 'required';
            }

			$validate = Rules::validate($input, $rules);

			if ( $validate )
				return $this->response($validate);

			$user = $this->_user->updateuser($input, $id);


		}
	}

}