<?php

namespace Front\Chords;

/**
 * ChordController
 *
 * @package RynelleCMS
 * @author  Rynelle Coronacion <dev.rynelle@gmail.com>
 * @version v1
 */

// REFERENCE for JS (PENDING)
// https://github.com/frigidrain/transposer

use Front\FrontBaseController;
use Themes;
use Input;

use Repositories\Chords\SongRepository;
use Repositories\Chords\ArtistRepository;

use Libraries\Chords\Transposer;

class ChordController extends FrontBaseController {

	public $view_path = 'chords.chords-tabs';

	/*
	 * Repositories\Chords\SongRepository
	 */
	private $_song;

	/*
	 * Repositories\Chords\ArtistRepository
	 */
	private $_artist;

	/*
	 * Libraries\Chords\Transposer
	 */
	private $_transposer;

	/*
	 * Get Random Songs
	 */
	private $randomsongs;

	/**
	 * Setup the layout used by the controller.
	 *
	 * @return void
	 */
	public function __construct( SongRepository $_song, ArtistRepository $_artist, Transposer $_transposer )
	{
		$this->_song       = $_song;
		$this->_artist     = $_artist;
		$this->_transposer = $_transposer;

		$randomsongs = $_song->random(['artist'], null, 10);
		$this->randomsongs = $randomsongs->toArray();
	}

	/**
	 * Setup the layout used by the controller.
	 *
	 * @return void
	 */
	public function getIndex()
	{

		$input = Input::get();
		$this->_song->perpage = 16;
		$getsongs = $this->_song->collections($input);
		$getsongs = $getsongs->appends(Input::except('page'));

		$data = [
					'pagetitle'   => 'Chords and Tabs Collection',
					'songs'   	  => $getsongs,
					'randomsongs' => $this->randomsongs,
					'input' 	  => $input,
				];
		return $this->view('index', $data);
	}

	/**
	 * Setup the layout used by the controller.
	 *
	 * @return void
	 */
	public function getSong($artist = null, $song = null, $isajax = false)
	{

		if ( $isajax !== false && $isajax !== 'true' )
			return $this->page404();

		$input   = Input::get();

		if ( $artist && $song ) {
			$getsong = $this->_song->get($song, 'slug');

			$transpose = intval(@$input['transpose']);
			$getsong->transpose = $this->_transposer->make($getsong->chords, $transpose);
			
			if ( $isajax === 'true' )
				return $this->response($getsong->transpose);

			if ( $getsong ) {

				$getartist = $this->_artist->getartist($artist, 'slug', true, true);

				if ( $getartist ) {

					$data = [
								'pagetitle' => $getsong->title . ' by '. $getartist->name,
								'is_chord'  => true,
								'song'      => $getsong,
								'artist'    => $getartist,
								'transpose' => $transpose,
							];

					return $this->view('details', $data);
				}
			}

			return $this->page404();
		}
		
		if ( $artist ) {

			$getartist   = $this->_artist->get($artist, 'slug');

			if ( $getartist ) {

				$getsongs = $this->_song->collections($input, $getartist->id, 'ASC');

				$data = [
							'is_artist'   => true,
							'artist'   	  => $getartist,
							'songs'   	  => $getsongs,
							'randomsongs' => $this->randomsongs,
						];
				return $this->view('index', $data);

			}

		}
		
		return $this->page404();
	}

}