<?php

namespace Front\Contacts;

/**
 * ContactController
 *
 * @package RynelleCMS
 * @author  Rynelle Coronacion <dev.rynelle@gmail.com>
 * @version v1
 */

use Front\FrontBaseController;

use Mail;
use Input;
use Validator;
use Carbon\Carbon;

class ContactController extends FrontBaseController {

    public $view_path = 'contacts';

	/**
	 * Setup the layout used by the controller.
	 *
	 * @return void
	 */
	public function __construct()
	{
		
	}

	/**
	 * Setup the layout used by the controller.
	 *
	 * @return void
	 */
	public function getIndex()
	{
		$data['pagetitle'] = "Get in Touch - Contact Us";
		return $this->view('index')->with($data);
	}

	/**
	 * Setup the layout used by the controller.
	 *
	 * @return void
	 */
	public function postSend()
	{
		$input = Input::all();
        $response  = [
                        'success' => false,
                        'errors'  => null
                     ];
        if ( $input ) {
            $rules = [
                        'name'    => 'required',
                        'email'   => 'required|email',
                        'message' => 'required'
                     ];

            $validator = Validator::make($input, $rules);

            if ( $validator->fails() )
            {

                $errors   = $validator->errors();
                $messages = [];

                foreach (array_keys($rules) as $required)
                {
                    if ( $errors->has($required) )
                    {
                        $messages[$required] = $errors->first($required);
                    }
                }

                $response['errors'] = $messages;
                
            }
            else
            {
                $email    = [
                                'name'    => $input['name'],
                                'email'   => $input['email'],
                                'content' => $input['message'],
                            ];
                            
                $authorEmail = [
                                    'site'         => setting('name'),
                                    'author'       => setting('author'),
                                    'author_email' => setting('author_email'),
                               ];

                // Send Mail
                Mail::send('emails.contact', $email, function($mail) use ($authorEmail, $email)
                {
                    $mail->from($email['email'], $email['name'])
                         ->subject('ONLINE INQUIRY: ' . $authorEmail['site'] . ' - ' . $email['name'])
                         ->to($authorEmail['author_email'])
                         ->replyTo($email['email']);
                });

                $response['success'] = true;

                // Logs
                $this->logs("Contact Form " . print_r($input, true));
            }
        }
        else
        {
            $response['errors'] = [ 'main' => 'Request input not be null' ];
        }

        return $this->response( $response );
	}


}