<?php

namespace Front;

/**
 * FrontBaseController
 *
 * @package RynelleCMS
 * @author  Rynelle Coronacion <dev.rynelle@gmail.com>
 * @version v1
 */

use Response;
use Controller;
use App;
use View;
use Themes;
use Input;

use Traits\Logger;

class FrontBaseController extends Controller {

	use Logger;
	
	/**
	 * Setup the layout used by the controller.
	 *
	 * @return void
	 */
	protected function view($view, $data = [])
	{
		$make_view = 'pages.';
		if ( @$this->view_path )
		{
			$make_view .= str_finish(@$this->view_path, '.');
		}
		$data['view_path']    = $make_view;
		$data['partial_path'] = 'partials.';
		$data['sortby'] 	  = Input::get('sort');

		return Themes::make( $make_view . $view )->with($data);
	}

	/**
	 * Set in Input Logs
	 * app/storage/logs/{date}
	 *
	 * @return void
	 */
	protected function logs( $message, $type = 'info' )
	{
        $this->log(__METHOD__, $type)->message(json_encode($message) . "\n");
	}

	/**
	 * Send Response in AJAX Request
	 *
	 * @return void
	 */
	protected function response( $data, $code = 200 )
	{
        return Response::json( $data, $code );
	}

	/**
	 * Return Page Not Found
	 *
	 * @return void
	 */
	protected function page404()
	{
        return App::abort(404);
	}

}
