<?php
class SettingsSeeder extends Seeder {

     /**
     * The console command instance.
     *
     * @var \Illuminate\Console\Command
     */
     protected $command;

     /**
     * Run the database seeds.
     *
     * @return void
     */
     public function run()
     {
          Eloquent::unguard();

          DB::transaction(function()
          {
               $this->command->info('>>> Settings ');
               $this->command->info(' Truncate Settings.');
               DB::table('settings')->truncate();

               $this->command->info(' Starting to seed Settings');

               foreach ($this->defaultSystemSettings() as $type => $settings) {
                    foreach ($settings as $key => $value) {
                         $data = [
                              'type'  => $type,
                              'code'  => $value['code'],
                              'label' => $value['label'],
                              'value' => $value['value'],
                         ];
                         DB::table('settings')->insert($data);
                    }
               }

               $this->command->info('SettingsSeeder table seeded!');
               $this->command->info('-------------------------------------');

          });
     }

     public function defaultSystemSettings()
     {
          $data = [
                    'general' => [
                                   [
                                        'code'  => 'name',
                                        'label' => 'Site Name',
                                        'value' => SITE_NAME . ' - CMS',
                                   ],
                                   [
                                        'code'  => 'shortname',
                                        'label' => 'Site Short Name',
                                        'value' => SITE_NAME,
                                   ],
                                   [
                                        'code'  => 'icon',
                                        'label' => 'Site Icon',
                                        'value' => 'http://imgholdr.com/32x32/transparent/ffb400/fa-music',
                                   ],
                                   [
                                        'code'  => 'logo',
                                        'label' => 'Site Logo',
                                        'value' => 'http://imgholdr.com/60x60/transparent/ffb400/fa-music',
                                   ],
                                   [
                                        'code'  => 'keywords',
                                        'label' => 'Site Keywords',
                                        'value' => SITE_NAME . ', chords, tabs, bass, guitar',
                                   ],
                                   [
                                        'code'  => 'description',
                                        'label' => 'Site Description',
                                        'value' => SITE_NAME . " is the search engine for guitar chords & tabs, bass tabs and other instruments.\nWe have over a thousand and thousand chords and tabs to learn.\nLets play and learn... ",
                                   ],
                                   [
                                        'code'  => 'banner',
                                        'label' => 'Site Banner',
                                        'value' => 'http://imgholdr.com/700x460/transparent/ffb400?text=' . SITE_NAME,
                                   ],
                                   [
                                        'code'  => 'banner_width',
                                        'label' => 'Site Banner Size (Width)',
                                        'value' => 700,
                                   ],
                                   [
                                        'code'  => 'banner_height',
                                        'label' => 'Site Banner Size (Height)',
                                        'value' => 460,
                                   ],
                                   [
                                        'code'  => 'author',
                                        'label' => 'Site Author',
                                        'value' => SITE_AUTHOR,
                                   ],
                                   [
                                        'code'  => 'author_email',
                                        'label' => 'Author Email',
                                        'value' => 'dev.rynelle@gmail.com',
                                   ],
                                   [
                                        'code'  => 'published_time' ,
                                        'label' => 'Site Publish Date/Time',
                                        'value' => date('Y-m-d H:i:s'),
                                   ],
                                 ],
                    'comment' => [
                                   [
                                        'code'  => 'comment_default',
                                        'label' => 'Set Default Comment Plugins [disqus or facebook]',
                                        'value' => 'disqus', // disqus | facebook
                                   ],
                                   [
                                        'code'  => 'comment_disqus' ,
                                        'label' => 'Disqus Script Code',
                                        'value' => "<div id=\"disqus_thread\"></div>
<script>

/**
*  RECOMMENDED CONFIGURATION VARIABLES: EDIT AND UNCOMMENT THE SECTION BELOW TO INSERT DYNAMIC VALUES FROM YOUR PLATFORM OR CMS.
*  LEARN WHY DEFINING THESE VARIABLES IS IMPORTANT: https://disqus.com/admin/universalcode/#configuration-variables*/
/*
var disqus_config = function () {
this.page.url = PAGE_URL;  // Replace PAGE_URL with your page's canonical URL variable
this.page.identifier = PAGE_IDENTIFIER; // Replace PAGE_IDENTIFIER with your page's unique identifier variable
};
*/
(function() { // DON'T EDIT BELOW THIS LINE
var d = document, s = d.createElement('script');
s.src = '//rynelle-com-1.disqus.com/embed.js';
s.setAttribute('data-timestamp', +new Date());
(d.head || d.body).appendChild(s);
})();
</script>
<noscript>Please enable JavaScript to view the <a href=\"https://disqus.com/?ref_noscript\">comments powered by Disqus.</a></noscript>",
                                   ],
                                   [
                                        'code'  => 'comment_facebook_appid',
                                        'label' => 'Facebook Application ID',
                                        'value' => '1759813094348401',
                                   ],
                                   [
                                        'code'  => 'comment_facebook',
                                        'label' => 'Facebook Script Code',
                                        'value' => "<div id=\"fb-root\"></div>
<script>(function(d, s, id) {
  var js, fjs = d.getElementsByTagName(s)[0];
  if (d.getElementById(id)) return;
  js = d.createElement(s); js.id = id;
  js.src = \"//connect.facebook.net/en_US/sdk.js#xfbml=1&version=v2.8&appId=FACEBOOK_APPID\";
  fjs.parentNode.insertBefore(js, fjs);
}(document, 'script', 'facebook-jssdk'));</script>
<div class=\"fb-comments\" data-href=\"FACEBOOK_URL\" data-width=\"100%\" data-numposts=\"20\"></div>",
                                   ],
                                 ],
                    'analytics' => [
                                        [
                                             'code'  => 'google_analytics_track_id',
                                             'label' => 'Google Analytics Tracking ID',
                                             'value' => 'UA-83155633-4',
                                        ],
                                        [
                                             'code'  => 'google_analytics',
                                             'label' => 'Google Analytics Code',
                                             'value' => "<script>
  (function(i,s,o,g,r,a,m){i['GoogleAnalyticsObject']=r;i[r]=i[r]||function(){
  (i[r].q=i[r].q||[]).push(arguments)},i[r].l=1*new Date();a=s.createElement(o),
  m=s.getElementsByTagName(o)[0];a.async=1;a.src=g;m.parentNode.insertBefore(a,m)
  })(window,document,'script','https://www.google-analytics.com/analytics.js','ga');

  ga('create', 'GOOGLE_TRACK_ID', 'auto');
  ga('send', 'pageview');

</script>",
                                        ],
                                   ],
                    'social' => [
                                        [
                                             'code'  => 'social_facebook',
                                             'label' => 'Facebook',
                                             'value' => '',
                                        ],
                                        [
                                             'code'  => 'social_twitter',
                                             'label' => 'Twitter',
                                             'value' => '',
                                        ],
                                        [
                                             'code'  => 'social_google',
                                             'label' => 'Google',
                                             'value' => '',
                                        ],
                                        [
                                             'code'  => 'social_instagram',
                                             'label' => 'Instagram',
                                             'value' => '',
                                        ],
                                        [
                                             'code'  => 'social_linkedin',
                                             'label' => 'Linkedin',
                                             'value' => '',
                                        ],
                                        [
                                             'code'  => 'social_tumblr',
                                             'label' => 'Tumblr',
                                             'value' => '',
                                        ],
                                        [
                                             'code'  => 'social_bitbucket',
                                             'label' => 'Bitbucket',
                                             'value' => '',
                                        ],
                                        [
                                             'code'  => 'social_dropbox',
                                             'label' => 'Dropbox',
                                             'value' => '',
                                        ],
                                        [
                                             'code'  => 'social_flickr',
                                             'label' => 'Flickr',
                                             'value' => '',
                                        ],
                                        [
                                             'code'  => 'social_foursquare',
                                             'label' => 'Foursquare',
                                             'value' => '',
                                        ],
                                        [
                                             'code'  => 'social_github',
                                             'label' => 'Github',
                                             'value' => '',
                                        ],
                                   ],
                  ];
          return $data;
     }
}

