<?php

use Models\Chords\Song;
use Models\Chords\Artist;
use Models\Chords\Type;

class SongsSeeder extends Seeder {

     /**
     * The console command instance.
     *
     * @var \Illuminate\Console\Command
     */
     protected $command;

     /**
     * Run the database seeds.
     *
     * @return void
     */
     public function run()
     {
          Eloquent::unguard();

          DB::transaction(function()
          {
               $this->command->info(' Truncate songs table.');

               DB::statement('SET FOREIGN_KEY_CHECKS=0;');

               Artist::truncate();
               Song::truncate();

               $artist = [ 
                              'name' => 'Misc Artist',
                              'slug' => 'misc-artist'
                         ];
               $artist   = Artist::create($artist);

               $chord_type = Type::where('slug', 'chords')->first();

               $separator = DIRECTORY_SEPARATOR;

               $dir       = str_replace("app{$separator}database{$separator}seeds", '', __DIR__);
               $directory = "{$dir}resources{$separator}chords{$separator}h2{$separator}";
               $files     = File::allFiles($directory);
               
               if ( $files ) {
                    $chords = [];
                    foreach ($files as $key => $file) {
                         $getcontent      = File::get($file);
                         $explode_content = explode('***/.', $getcontent);
                         $filecontent     = trim(@$explode_content[1]);

                         if ( $filecontent ) {
                              $content  = Crypt::decrypt($filecontent);
                              $contents = explode('#_#_#', $content);
                              $label_separator = '__:__';

                              if ( $contents ) {

                                   $data = [
                                               'title'      => null,
                                               'chords'     => null,
                                               'artist_id'  => $artist->id,
                                               'type_id'    => $chord_type->id,
                                               'difficulty' => 1,
                                               'version'    => 1
                                           ];

                                   foreach ($contents as $song) {

                                        if ( $song ) {

                                             if ( strpos($song, "version{$label_separator}") !== false ) {
                                                  $version = str_replace("version{$label_separator}", '', $song);
                                                  $version = intval($version);
                                                  $data['version'] = ( $version == 0 ) ? 1 : $version;
                                             }

                                             if ( strpos($song, "title{$label_separator}") !== false ) {
                                                  $title = str_replace("title{$label_separator}", '', $song);
                                                  $title = str_replace(['Chords', 'chords'], '', $title);
                                                  $data['title'] = trim($title);
                                             }
                                             if ( strpos($song, "artist{$label_separator}") !== false ) {
                                                  $artist_name = str_replace("artist{$label_separator}", '', $song);
                                                  $artist_slug = str_slug($artist_name);

                                                  $artist   = Artist::where('slug', $artist_slug)->first();
                                                  if ( !$artist ) {
                                                       $artist = [ 
                                                                      'name' => $artist_name,
                                                                      'slug' => $artist_slug
                                                                 ];
                                                       $artist   = Artist::create($artist);
                                                  }
                                                  $data['artist_id'] = $artist->id;

                                             }
                                             if ( strpos($song, "type{$label_separator}") !== false ) {
                                                  $type_code = str_replace("type{$label_separator}", '', $song);
                                                  $type      = Type::where('slug', $type_code)->first();
                                                  if ( $type ) 
                                                       $data['type_id'] = $type->id;

                                             }

                                             if ( strpos($song, "difficulty{$label_separator}") !== false ) {
                                                  $data['difficulty'] = str_replace("difficulty{$label_separator}", '', $song);
                                             }

                                             if ( strpos($song, "chords{$label_separator}") !== false ) {
                                                  $data['chords'] = str_replace("chords{$label_separator}", '', $song);
                                             }

                                        }

                                   }

                                   if ( $data['title'] && $data['chords'] ) {

                                        if ( $data['version'] > 1 )
                                             $data['title'] .= ' v' . $data['version'];

                                        $slug = str_slug($data['title']);
                                        $song = Song::where('slug', $slug)->first();
                                        if ( $song )
                                             $slug = encrypt(rand(10, 99)) . '_' . $slug;
                                        $data['slug'] = $slug;

                                        Song::create($data);

                                   }
                              }
                         }

                    }
               }

               $this->command->info('SongsSeeder table seeded!');
               $this->command->info('-------------------------------------');

          });
     }
}

