<?php

/**
 * UserTableSeeder Class
 *
 * Provide Seeder for our User Related Account
 *
 *
 * @package PA Seeder
 * @author  Magente Dev Team <Anthony Pillos>
 * @version v1
 */
class UsersSeeder extends Seeder {

        /**
         * The console command instance.
         *
         * @var \Illuminate\Console\Command
         */
        protected $command;

        /**
         * Run the database seeds.
         *
         * @return void
         */
        public function run()
        {
                Eloquent::unguard();

                DB::transaction(function()
                {

                    DB::statement('SET FOREIGN_KEY_CHECKS=0;');

                    DB::table('users')->truncate();
                    DB::table('users_groups')->truncate();
                    DB::table('groups')->truncate();
                    DB::table('throttle')->truncate();

                    $this->createGroups();
                    $this->createUsers();
                    
                   $this->command->info('UsersSeeder table seeded!');
                   $this->command->info('-------------------------------------');

                });

        }

        /**
         * Run the database seeds.
         *
         * @return void
         */
        private function createGroups()
        {
            $createGroup = [
                [
                    'name'        => SENTRY_ADMINISTRATOR,
                    'permissions' => [
                                        'administrator.admin' => 1
                                     ]
                ]
            ];
            foreach ($createGroup as $key => $groupname) {
                Sentry::createGroup($groupname);
            }
            $this->command->info('> `users_groups` Table Seeded!');

        }

        /**
         * Run the database seeds.
         *
         * @return void
         */
        private function createUsers()
        {
            
            $createDefaultUser = [
                [
                    'email'     => 'demo@email.com',
                    'username'  => 'demo',
                    'password'  => 'demo',
                    'activated' => true,
                    'first_name'=> 'Demo',
                    'last_name' => 'Demo',
                    'group_id'  => 1,
                    'activation_code' => str_random(32)
                ]
            ];

            $defaultGroupID = 2;
            foreach ($createDefaultUser as $key => $createuser) {

                $group_id = $createuser['group_id'];
                unset($createuser['group_id']);

                $user = Sentry::createUser($createuser);

                $group = Sentry::findGroupById($group_id);
                $user->addGroup($group);

            }
            $this->command->info('> `users` Table Seeded!');


        }

}