<?php

/**
* pre()
* short hand for printing array/string data
*
* @return array/string
**/
if ( !function_exists('pre') )
{
    function pre($str, $return = false, $attr = null)
    {
        echo "<pre {$attr}>";
        return print_r($str, $return);
        echo "</pre>";
    }
}

/**
* pre()
* short hand for printing array/string data
*
* @return array/string
**/
if ( !function_exists('all_routes') )
{
    function reserve_words()
    {
        $routeCollection = Route::getRoutes();
        $routes = [];
        foreach ($routeCollection as $value) {
            $_path = $value->getPath();
            $_path = explode('/', $_path);
            $path  = reset($_path);
            $path  = preg_replace('/[^\w-.]/', '', $path);
            if ( !in_array($path, $routes) && $path) {
                $routes[] = $path;
            }
        }

        return $routes;
    }
}

/**
* img_placeholder()
* short hand for printing array/string data
*
* @return array/string
**/
if ( !function_exists('img_placeholder') )
{
    function img_placeholder($size = '160x160', $background = '3c8dbc', $color = 'ffffff', $text = null)
    {
        $url  = "http://imgholdr.com/";
        $url .= $size;

        if ( is_bool($color) ) {
            $url .= "/03c9db/ffffff";
        }
        else {
            $url .= "/$background";
            $url .= "/$color";
        }

        if ( is_bool($color) || $text !== null ) {
            $url .= "?text=";
            $url .= is_bool($color) ? $background : $text;
        }

        return $url;
    }
}

/**
* Youtube video key
*
* @return array/string
**/
if ( !function_exists('youtube_key') )
{
    function youtube_key($video)
    {
       if ( strpos($video, 'youtube.com') !== false ) {

            preg_match("/^(?:http(?:s)?:\/\/)?(?:www\.)?(?:m\.)?(?:youtu\.be\/|youtube\.com\/(?:(?:watch)?\?(?:.*&)?v(?:i)?=|(?:embed|v|vi|user)\/))([^\?&\"'>]+)/",
                        $video,
                        $matches);

            if ( @$matches[1] ) 
                return $matches[1];
        }

        return null;
    }
}

/**
* build_asset()
* We used this for getting our js/css file assets and for generating build
* in our productions.
*
* @return void
**/
if (!function_exists('build_asset')) {

  function build_asset($file, $is_theme = false)
  {

    if ( $is_theme === true ) {
        $theme_env = env('APP_THEME', 'default');
        $file      = "{$theme_env}/$file";
    }

    return asset($file);
  }
}

/**
* theme_asset()
* We used this for getting our js, css, img, fonts, etc. file for themes
*
* @return void
**/
if (!function_exists('theme_asset')) {

  function theme_asset($file)
  {
    return build_asset($file, true);
  }
}

/**
 * Generate a URL friendly "slug" from a given string.
 *
 * @param  string  $title
 * @param  string  $separator
 * @return string
 */
if (! function_exists('str_slug')) {
    function str_slug($title, $separator = '-')
    {
        return Str::slug($title, $separator);
    }
}

/**
* url_active()
* Check if the page is Current URL
*
* @return array/string
**/
if ( !function_exists('url_active') )
{
    function url_active($route, $active = 'active')
    {
        if ( is_array($route) ) {

            $route = array_map(function($r) {
                return URL::route($r);
            }, $route);

            if ( in_array(URL::current(), $route) ) {
                return $active;
            }
            return '';
        }
        else
            return URL::route($route) === URL::current() ? $active : '';
    }
}

/**
* url_active()
* Check if the page is Current URL
*
* @return array/string
**/
if ( !function_exists('current_url') )
{
    function current_url()
    {
        return Request::url();
    }
}


/**
* encrypt()
* Encrypt string
*
* @return void
**/
if (!function_exists('encrypt'))
{
    function encrypt($str = null)
    {
        if ( $str === null )
            $str = time();
        
        return Hashids::encode($str, rand(100,999));
    }
}

/**
* decrypt()
* Decrpyt string
*
* @return void
**/
if (!function_exists('decrypt'))
{
    function decrypt($str)
    {
        try
        {
            $decrypt = Hashids::decode($str);
            return array_shift($decrypt);
        }
        catch (\Illuminate\Encryption\DecryptException $e)
        {
            throw new \Libraries\Exceptions\SystemError(sprintf("Cannot Decrypt (%s), Hash key does'nt match.",$str), ERC_BAD_REQUEST);

        }
    }
}

/**
* setting()
* Format Price Display
*
* @param (integer)  $price
* @param (string)   $currency
* @return void
**/
if (!function_exists('setting'))
{
    function setting($code, $value = true)
    {
        $setting = App::make('Repositories\System\SettingRepository');
        return $setting->getSetting($code, 'code', true, $value);
    }
}

if (!function_exists('parseJSON'))
{
    function parseJSON($str) {

        if ( is_array($str) === true || is_object($str) === true )
            $str = json_encode($str);

        $str = str_replace("\\", "\\\\", $str);
        $str = str_replace("'", "\\'", $str);

        return $str;
    }
}


/**
* roundNum()
* Remove Hidden Character and also remove whitespaces
*
* @param $string
* @return void
* @access private
**/
if( !function_exists('roundNum') )
{
    function roundNum( $num, $isInt = false ) {

        $decimal = ( $isInt ) ? $isInt : 0;
        $num = str_replace(',', '', $num);
        $num = floatval($num);
        $num = number_format($num, $decimal, '.', '');
        return round( $num, $decimal, PHP_ROUND_HALF_UP );
    }
}

/**
* gets the data from a URL
*
* @param $d Object
* @return array
*/
if ( ! function_exists('getURLData')) {
    function getURLData($url, $htmlentities = false) {
        $ch = curl_init();
        $timeout = 30;
        curl_setopt($ch, CURLOPT_URL, $url);
        curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
        curl_setopt($ch, CURLOPT_CONNECTTIMEOUT, $timeout);
        curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, false);

        $data = curl_exec($ch);
        curl_close($ch);

        return ( $htmlentities == true ) ? htmlentities($data) : $data;

    }
}


/**
 * Generate a URL friendly "slug" from a given string.
 *
 * @param  string  $title
 * @param  string  $separator
 * @return string
 */
if (! function_exists('difficulty')) {
    function difficulty($num = 1, $invert = false)
    {
        
        if ( $invert === false ) {
            $label = 'Novice';
            if ( $num == 2)
                $label = 'Intermediate';
            elseif ( $num == 2)
                $label = 'Advanced';
        }
        else {
            $num   = strtolower($num);
            $label = 1;
            if ( $num == 'intermediate')
                $label = 2;
            elseif ( $num == 'advanced')
                $label = 3;

        }

        return $label;
    }
}

/**
 * Comments Plugin
 *
 * @param  string  $artist
 * @param  string  $chords
 * @return string
 */
if (! function_exists('commentPlugin')) {
    function commentPlugin($artist = null, $chords = null)
    {
        
        $url            = route(ROUTE_FRONT_HOME_INDEX);
        $identifier_url = ( $artist !== null && $chords !== null ) ? route(ROUTE_FRONT_CHORDS_ARTIST_SONG, [$artist, $chords]) : $url;
        $comment_detault = setting('comment_default');
        $comment_detault = strtolower($comment_detault);

        if ( $comment_detault == 'facebook' ) {
            $comment_facebook_id = setting('comment_facebook_appid');
            $comment_facebook    = setting('comment_facebook');

            $comment_facebook = str_replace('FACEBOOK_URL', $identifier_url, $comment_facebook);
            return str_replace('FACEBOOK_APPID', $comment_facebook_id, $comment_facebook);

        }
        elseif ( $comment_detault =='disqus' ) {
            $comment_disqus = setting('comment_disqus');
            $comment_disqus = str_replace('PAGE_URL', $url, $comment_disqus);

            return str_replace('PAGE_IDENTIFIER', $identifier_url, $comment_disqus);

        }

        return null;

    }
}

/**
 * Google Analytics
 *
 * @param  string  $title
 * @param  string  $separator
 * @return string
 */
if (! function_exists('googleAnalytics')) {
    function googleAnalytics()
    {
        
        $track_id = setting('google_analytics_track_id');
        $google_analytics = setting('google_analytics');

        if ( $track_id && $google_analytics )
            return str_replace('GOOGLE_TRACK_ID', $track_id, $google_analytics);

        return null;

    }
}


/**
 * @param  array       $inputfile
 * @param  array       $filesave_path
 * @return string
 */
if ( ! function_exists('uploadSave'))
{
   
    function uploadSave( $inputfile, $filesave_path )
    {

        if ( !File::exists($filesave_path) )
        {
            File::makeDirectory($filesave_path, 0777, true, true);
        }

        $file_filename  = $inputfile->getClientOriginalName();
        $file_extension = $inputfile->getClientOriginalExtension();
        $file_filesize  = $inputfile->getSize();

        $filepath = str_finish($filesave_path, '/');
        
        $filename = str_replace(".{$file_extension}", '', $file_filename);
        $filename = str_slug($filename, '_') . '_' . uniqid();

        // Original Image
        \Image::make($inputfile)->save("{$filepath}{$filename}.{$file_extension}");

        $path = str_replace(storage_path(), '', "{$filepath}{$filename}.{$file_extension}");
        $path = ltrim($path, '/');
        return [
            'filename'  => "{$filename}.{$file_extension}",
            'path'      => $path,
            'name'      => $file_filename,
            'extension' => $file_extension,
            'size'      => $file_filesize,
        ];

    }
}
