<?php

namespace Libraries\Chords;

/**
 * Scraper
 *
 * @package RynelleCMS
 * @author  Rynelle Coronacion <dev.rynelle@gmail.com>
 * @version v1
 */

use App;

class Scraper
{
    
    public $origin = SITE_ULTIMATE_GUITAR;

    public $html;

    private $tags   = [];

    public function init($url) {

        $ch = curl_init();
        
        curl_setopt($ch, CURLOPT_URL, $url);
        curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
        curl_setopt($ch, CURLOPT_CONNECTTIMEOUT, 300);
        curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, false);
        
        $this->html = curl_exec($ch);
        curl_close($ch);

        $this->sitelocation($url);

        return $this;

    }

    public function validate() {
        $title = $this->title();
        return strlen($title) > 0;
    }

    public function title() {

        if ( $this->origin == SITE_ULTIMATE_GUITAR ) {
            $title = $this->extract('title');
            return $title;
        }
        return null;
    }

    public function version() {

        if ( !$this->validate() )
            return null;

        if ( $this->origin == SITE_ULTIMATE_GUITAR ) {

            $html_version = $this->extract('version');

            $version = strip_tags($html_version);
            $version = filter_var($version, FILTER_SANITIZE_NUMBER_INT);
            $version = floatval($version);

            if ( $version == 0 )
                return '';

            return $version;

        }
        return null;
    }

    public function type() {

        if ( !$this->validate() )
            return null;

        $title = $this->title();

        if ( strpos(strtolower($title), 'drum') !== false )
            return 'drum';

        elseif ( strpos(strtolower($title), 'ukulele') !== false )
            return 'ukulele';

        elseif ( strpos(strtolower($title), 'bass') !== false )
            return 'bass';

        elseif ( strpos(strtolower($title), 'tab') !== false &&
                 strpos(strtolower($title), 'pro tab') === false &&
                 strpos(strtolower($title), 'power tab') === false )
            return 'tabs';

        return 'chords';
        
    }

    public function author() {


        if ( !$this->validate() )
            return null;

        if ( $this->origin == SITE_ULTIMATE_GUITAR ) {
            $html_author = $this->extract('author');

            $author = strip_tags($html_author);
            $author = str_replace('by', '', $author);
            
            return trim($author);

        }
        return null;
        
    }

    public function difficulty($is_num = true) {

        if ( !$this->validate() )
            return null;
        
        $difficulty = 'novice';

        if ( $this->origin == SITE_ULTIMATE_GUITAR ) {

            $html_difficulty = $this->extract('difficulty');

            $difficulties = explode(',', STR_DIFFICULTIES);
            for ($d=0; $d < count($difficulties); $d++) { 
                if ( strpos(strtolower($html_difficulty), $difficulties[$d]) !== false ) {
                    $difficulty = $difficulties[$d];
                    break;
                }
            }
        }
        return difficulty($difficulty, $is_num);
        
    }

    public function chords() {

        if ( !$this->validate() )
            return null;
        
        if ( $this->origin == SITE_ULTIMATE_GUITAR ) {

            $html_chords = $this->extract('chords');
            return str_replace(['<span>', '</span>'], '', $html_chords);

        }
        return null;
        
    }

    private function sitelocation($url) {

        if ( strpos($url, SITE_ULTIMATE_GUITAR) !== false ) {

            $this->origin = SITE_ULTIMATE_GUITAR;

            $this->tags['title']      = [
                                            'element'   => 'h1',
                                            'attribute' => 'itemprop="name"'
                                        ];

            $this->tags['version']    = [
                                            'element'   => 'div',
                                            'attribute' => 'class="t_version"'
                                        ];

            $this->tags['author']     = [
                                            'element'   => 'div',
                                            'attribute' => 'class="t_autor"'
                                        ];

            $this->tags['difficulty'] = [
                                            'element'   => 'div',
                                            'attribute' => 'class="t_dtd"'
                                        ];

            $this->tags['chords']     = [
                                            'element'   => 'pre',
                                            'attribute' => 'class="js-tab-content"'
                                        ];

        }

    }

    private function extract($get, $tag = null, $extra = null, $ismultiple = false) {

        if ( $tag === null )
            $tag = @$this->tags[$get]['element'];

        if ( $extra === null )
            $extra = @$this->tags[$get]['attribute'];
        
        $pattern = '{<' . $tag . ' .*?' . $extra . '.*?>((?:(?:(?!<' . $tag . '[^>]*>|</' . $tag . '>).)++|<' . $tag . '[^>]*>(?1)</' . $tag . '>)*)</' . $tag . '>}six';
        
        preg_match_all($pattern, $this->html, $matches); 

        $response = @$matches[1];
        
        if ( $ismultiple === true )
            return $response;

        return reset($response);
    }

    private function advanceExtract( $html, $tag ){
         
        $selfclosing_tags = array( 'area', 'base', 'basefont', 'br', 'hr', 'input', 'img', 'link', 'meta', 'col', 'param' );
        $selfclosing      = in_array( $tag, $selfclosing_tags );
        if ( $selfclosing ){
            $tag_pattern = 
                '@<(?P<tag>'.$tag.')           # <tag
                (?P<attributes>\s[^>]+)?       # attributes, if any
                \s*/?>                   # /> or just >, being lenient here 
                @xsi';
        } else {
            $tag_pattern = 
                '@<(?P<tag>'.$tag.')           # <tag
                (?P<attributes>\s[^>]+)?       # attributes, if any
                \s*>                 # >
                (?P<contents>.*?)         # tag contents
                </(?P=tag)>               # the closing </tag>
                @xsi';
        }
         
        $attribute_pattern = 
            '@
            (?P<name>\w+)                         # attribute name
            \s*=\s*
            (
                (?P<quote>[\"\'])(?P<value_quoted>.*?)(?P=quote)    # a quoted value
                |                           # or
                (?P<value_unquoted>[^\s"\']+?)(?:\s+|$)           # an unquoted value (terminated by whitespace or EOF) 
            )
            @xsi';
     
        if ( !preg_match_all($tag_pattern, $html, $matches, PREG_SET_ORDER | PREG_OFFSET_CAPTURE ) ){
            return array();
        }
         
        $tags = array();
        foreach ($matches as $match){
            $attributes = array();
            if ( !empty($match['attributes'][0]) ){ 
                 
                if ( preg_match_all( $attribute_pattern, $match['attributes'][0], $attribute_data, PREG_SET_ORDER ) ){
                    foreach($attribute_data as $attr){
                        if( !empty($attr['value_quoted']) ){
                            $value = $attr['value_quoted'];
                        } else if( !empty($attr['value_unquoted']) ){
                            $value = $attr['value_unquoted'];
                        } else {
                            $value = '';
                        }
                        $value = html_entity_decode( $value, ENT_QUOTES, 'ISO-8859-1' );
                         
                        $attributes[$attr['name']] = $value;
                    }
                }
                 
            }
             
            $tag = array(
                'tag_name' => $match['tag'][0],
                'offset' => $match[0][1], 
                'contents' => !empty($match['contents'])?$match['contents'][0]:'',
                'attributes' => $attributes, 
            );
              
            $tags[] = $tag;
        }
         
        return $tags;
    }

    public function search($value, $page = 1, $type = 'title')
    {

        $url = "https://www.ultimate-guitar.com/search.php?search_type={$type}&value={$value}";
        if ( $page > 1 )
            $url .= "&page={$page}";

        $this->init($url);

        $tresults = $this->extract([], 'table', 'class="tresults"');
        $extracted  = $this->advanceExtract($tresults, 'a');

        $data = [];
        if ( $extracted ) {
            $artist = null;
            foreach ($extracted as $extract) {
                $class    = @$extract['attributes']['class'];
                $contents = @$extract['contents'];
                if ( $class && $contents ) {
                    $type = null;
                    $href = null;

                    if ( strpos($class, 'search_art') !== false )
                        $artist = $contents;

                    if ( strpos($class, 'js-tp_link') !== false ) {
                        $type = 'UG Pro Version';
                    }
                    elseif ( strpos($class, 'result-link') !== false ) {
                        $href = @$extract['attributes']['href'];

                        $checkhref = str_replace('https://tabs.ultimate-guitar.com', '', $href);
                        $type = 'Chords';
                        
                        if ( strpos($checkhref, 'ukulele_crd') !== false ) {
                            $type = 'Ukulele';
                        }
                        elseif ( strpos($checkhref, 'drum_tab') !== false ) {
                            $type = 'Drum';
                        }
                        elseif ( strpos($checkhref, 'tab') !== false ) {
                            $type = 'Tab';
                        }
                            
                    }
                    if ( $type ) {

                        $title = trim(strip_tags($contents));
                        $title = str_replace('&nbsp;', ' ', $title);

                        $data[] = [
                                     '_id'    => uniqid(),
                                     'type'   => $type,
                                     'href'   => $href,
                                     'artist' => trim(strip_tags($artist)),
                                     'title'  => $title
                                  ];
                    }
                }
            }
        }

        $paging  = $this->extract([], 'div', 'class="paging"');
        $pagings = $this->advanceExtract($paging, 'a');
        
        $pagingcount = 1;
        if ( $pagings ) {
            foreach ($pagings as $paging) {
                $p = intval($paging['contents']);
                if ( $p > 0 )
                    $pagingcount++;
            }
        }

        return [
                    'paging' => $pagingcount,
                    'data'   => $data,
                    'page'   => $page,
               ];

    }

}
