<?php

namespace Models\Chords;

/**
 * Artist Class
 *
 * @package RynelleCMS
 * @author  Rynelle Coronacion <dev.rynelle@gmail.com>
 * @version v1
 */

use Model\Base\BaseModel;

use SoftDeletingTrait;
use Eloquent;
use App;
use Traits\HashIdTrait;

use Libraries\FileSystem\Asset;

class Artist extends BaseModel  {

    use SoftDeletingTrait;
    
    use HashIdTrait;

    /**
     * The database table used by the model.
     *
     * @var string
     */
    protected $table    = 'artists';
    
    protected $dates    = ['deleted_at'];

    protected $appends  = ['hash_id', 'image'];

    protected $fillable = [
        'name',
        'slug',
        'description',
        'avatar'
    ];

    public function songs()
    {
        return $this->hasMany('Models\Chords\Song')->orderBy('created_at', 'DESC');
    }

    /**
     * getFullNameAttribute
     *
     *
     * @access  public
     */
    public function getImageAttribute() {

        if ( $this->avatar ) {
            $asset = App::make('Libraries\FileSystem\Asset');
            return $asset->setAssetUrl( $this->avatar );
        }
        return null;
    }

}