<?php

namespace Models\Chords;

/**
 * Song Class
 *
 * @package RynelleCMS
 * @author  Rynelle Coronacion <dev.rynelle@gmail.com>
 * @version v1
 */

use Model\Base\BaseModel;

use SoftDeletingTrait;
use Traits\HashIdTrait;
use Eloquent;

class Song extends BaseModel  {

    use SoftDeletingTrait;

    use HashIdTrait;

    /**
     * The database table used by the model.
     *
     * @var string
     */
    protected $table    = 'songs';
    
    protected $dates    = ['deleted_at'];

    protected $appends  = ['hash_id', 'difficulty_name', 'thumbnail', 'embed'];

    protected $fillable = [
        'artist_id',
        'type_id',
        'title',
        'slug',
        'version',
        'difficulty',
        'capo',
        'chords',
        'video',
    ];

    public function type()
    {
        return $this->belongsTo('Models\Chords\Type');
    }

    public function artist()
    {
        return $this->belongsTo('Models\Chords\Artist');
    }

    /**
     * getFullNameAttribute
     *
     *
     * @access  public
     */
    public function getDifficultyNameAttribute() {
        
        return difficulty(intval($this->difficulty));
        
    }

    /**
     * getFullNameAttribute
     *
     *
     * @access  public
     */
    public function getThumbnailAttribute() {
        
        $youtube_key = youtube_key($this->video);

        if ( $youtube_key )
            return 'https://img.youtube.com/vi/' . $youtube_key . '/hqdefault.jpg';

        $first     = substr($this->title, 0, 1);
        $random_bg = sprintf('%06X', mt_rand(0, 0xFFFFFF));

        return 'http://imgholdr.com/480x360/ffffff/202020?text=' . strtolower($first);
    }

    /**
     * getFullNameAttribute
     *
     *
     * @access  public
     */
    public function getEmbedAttribute() {
        
        $youtube_key = youtube_key($this->video);

        if ( $youtube_key )
            return 'https://www.youtube.com/embed/' . $youtube_key;

        return null;
    }

}