<?php

namespace Repositories\Chords;

/**
 * ArtistRepository
 *
 * @package RynelleCMS
 * @author  Rynelle Coronacion <dev.rynelle@gmail.com>
 * @version v1
 */

use Repositories\Base\Repository;

class ArtistRepository extends Repository
{

    protected $modelclass = 'Models\Chords\Artist';

    public $perpage = 20;

    public function getartist($code, $field = 'slug', $first = true, $limit = false)
    {
        $query = $this->model->with('songs')->where($field, $code);

        if ( $first === false )
            return $query->get();

        if ( $limit === true )
            $query = $query->limit(10);

        return $query->first();
    }

    /**
     * @return void
     * @access public
     */
    public function collections($input, $array = false)
    {
        $search = @$input['search'] ?: @$input['s'];
        $letter = @$input['letter'] ?: @$input['l'];

        $sortby   = @$input['sort'] ?: 'newest';
        $sortkey  = 'created_at';
        $sorttype = 'DESC';
        if ( $sortby == 'alphabetically' ) {
            $sortkey  = 'name';
            $sorttype = 'ASC';
        }

        $query  = $this->model->with('songs');

        if ( $array === true ) {
            $datas  = [];
            $artists = $query->orderBy($sortkey, $sorttype)->get();
            foreach ($artists as $artist) {
                $datas[] = [
                                '_id'   => $artist->id,
                                'name'  => $artist->name,
                                'slug'  => $artist->slug,
                                'group' => '', // strtoupper(substr($artist->name, 0, 1))
                           ];
            }

            return $datas;
        }

        if ( $search )
            $query = $query->where('name',  'LIKE', '%' . $search . '%');

        if ( $letter ) {
            if ( $letter == '0-9' )
                $query = $query->where('name', 'REGEXP', '^[^A-Za-z]');
            else
                $query = $query->where('name', 'LIKE', $letter . '%');
        }

        return $query->orderBy($sortkey, $sorttype)->paginate( $this->perpage );
    }

}