###*
# Artist App
# Artist Controller
#
# @class ArtistApp
# @author Rynelle Coronacion <dev.rynelle@gmail.com>
###


window.Cms.ArtistApp.controller "ArtistController",
[
    '$scope'
    'routeApi'
    '$timeout'
    '$window'
    '$modal'
    'Upload'

    (
        $scope
        $routeapi
        $timeout
        $window
        $modal
        $upload
    ) ->

        class ArtistController
            
            ###
            # Controller Initializer
            ###
            constructor : () ->

                $scope.search = ''
                $scope.pagination =
                    total   : 0
                    current : 1
                
                $scope.cancelForm()
                $scope.getCollection()

                return

            ###
            # Get Collections
            ###
            $scope.getCollection = (page) ->
                
                $scope.loading = true
                data = {}
                page = $scope.pagination.current if angular.isUndefined page

                url  = $window.Routes.GetCollection
                url += '?search-token=' + $str_random 32
                data.page   = page if angular.isDefined page
                data.search = $scope.search if angular.isDefined $scope.search

                $routeapi.send url, data, 'POST'
                .then ( response ) ->

                    $scope.artists = []
                    data = response.data

                    if response.status is 200

                        $scope.artists = data.data

                        $scope.pagination = 
                            total   : data.total
                            current : data.current_page
                            max     : 20

                    $scope.loading = false

                    return

                return

            ###
            # Pagination Change Page
            ###
            $scope.pageChanged = () ->
                $scope.getCollection $scope.pagination.current
                return

            ###
            # Name Slug
            ###
            $scope.nameSlug = () -> $scope.form.slug = $scope.form.name.toLowerCase().replace /[^a-zA-Z0-9]+/g, '-'

            ###
            # Form Edit
            ###
            $scope.addEditform = (artist) ->

                $scope.display = 'form'

                $scope.files = []
                details = []
                details = JSON.parse artist.description if artist?.description

                if artist?.image
                    $scope.files.push
                        name  : artist?.image
                        thumb : artist?.image
                        exist : true

                $scope.form    = 
                    _id     : artist?.id    || $str_random 12
                    name    : artist?.name  || ''
                    slug    : artist?.slug  || ''
                    details : details

                $scope.details =
                    name  : ''
                    value : ''

                return

            $scope.addMoreDetails = () ->

                details = angular.copy $scope.details
                if details.name.length > 0 and details.value.length > 0
                    $scope.form.details.push details
                    $scope.details.name  = ''
                    $scope.details.value = ''

                return

            $scope.deleteDetail = (index) -> $scope.form.details.splice index, 1

            ###
            # Cancel/Reset Form or other variables
            ###
            $scope.cancelForm = () ->
                $scope.display    = 'lists'
                $scope.error      = {}
                $scope.form       = {}
                $scope.onsuccess   = false
                $scope.onsubmit    = false
                $scope.onmessage   = ''
                $scope.modalartist = {}

                return

            ###*
            #
            # @return submit
            ###
            $scope.submit = () ->

                $scope.onsubmit = true

                data = $scope.form
                data.file = _.last $scope.files

                $upload.upload
                    url  : $window.Routes.SubmitForm
                    data : data
                .then (response) ->
                    
                    _data = response.data
                    $scope.error   = {}

                    if response.status is 200

                        if _data?.errors
                            $scope.onsubmit = false
                            $scope.error    = _data.errors
                        else
                            $scope.onsuccess = true
                            $scope.onmessage = _data

                            $timeout ->
                                $scope.cancelForm()
                                $scope.getCollection()
                            , 2000


                , null, (evt) ->
                    progressPercentage = parseInt(100.0 * evt.loaded / evt.total)
                    evt.config._file?.progress = progressPercentage
                    return


                return

            ###
            # Close Modal
            ###
            $scope.closeModal = () -> $scope.modalInstance.dismiss("cancel") if $scope.modalInstance

            ###
            # Delete Collection Modal
            ###
            $scope.delete = (artist) ->

                $scope.modalartist    = artist
                $scope.onsubmitdelete = false

                $scope.modalInstance = $modal.open
                    templateUrl : "MODAL_DELETE_ARTIST"
                    size        : 'md'
                    scope       : $scope
                    backdrop    : 'static'
                    keyboard    : false

                return

            ###
            # Confirm Delete
            ###
            $scope.deleteConfirm = () ->
                $scope.onsubmitdelete = true

                url  = $window.Routes.DeleteArtist
                data = 
                    _id : $scope.modalartist.id

                $routeapi.send url, data, 'POST'
                .then ( response ) -> 
                    $scope.closeModal()
                    $scope.cancelForm()
                    $scope.getCollection()
 
                return

        new ArtistController()

]