###*
# Song App
# Song Controller
#
# @class SongApp
# @author Rynelle Coronacion <dev.rynelle@gmail.com>
###

window.Cms.SongApp.controller "SongController",
[
    '$scope'
    'routeApi'
    '$timeout'
    '$window'
    '$modal'

    (
        $scope
        $routeapi
        $timeout
        $window
        $modal
    ) ->

        class SongController
            
            ###
            # Controller Initializer
            ###
            constructor : () ->

                $scope.search = ''
                $scope.scrapsearch = ''
                $scope.pagination =
                    total   : 0
                    current : 1

                $scope.types = $window.Vars.Types

                $scope.capos = []
                for c in [0..12] by 1

                    if c is 0
                        caponame = 'No Capo'
                    else if c is 1
                        caponame = '1st fret'
                    else if c is 2
                        caponame = '2nd fret'
                    else if c is 3
                        caponame = '3rd fret'
                    else
                        caponame = c + 'th fret'
                    capo = 
                        id   : c
                        name : caponame

                    $scope.capos.push capo

                $scope.difficulties = [
                    { id : 1, name : 'Novice' }
                    { id : 2, name : 'Intermediate' }
                    { id : 3, name : 'Advanced' }
                ]
                
                $scope.cancelForm()

                $scope.getArtists()
                $scope.getCollection()
                $scope.multiScraper()

                # temp

                return

            ###
            # Get Collections
            ###
            $scope.getArtists = () ->

                $scope.artists = []

                url  = $window.Routes.Artists
                url += '?search-token=' + $str_random 32

                $routeapi.send url, {}, 'POST'
                .then ( response ) -> $scope.artists = response.data

                return

            ###
            # Get Collections
            ###
            $scope.getCollection = (page) ->
                
                $scope.loading = true
                data = {}
                page = $scope.pagination.current if angular.isUndefined page

                url  = $window.Routes.GetCollection
                url += '?search-token=' + $str_random 32
                data.page   = page if angular.isDefined page
                data.search = $scope.search if angular.isDefined $scope.search

                $routeapi.send url, data, 'POST'
                .then ( response ) ->

                    $scope.songs = []
                    data = response.data

                    if response.status is 200

                        $scope.songs = data.data

                        $scope.pagination = 
                            total   : data.total
                            current : data.current_page
                            max     : 20

                    $scope.loading = false

                    return

                return

            ###
            # Pagination Change Page
            ###
            $scope.pageChanged = () ->
                $scope.getCollection $scope.pagination.current
                return

            ###
            # Name Slug
            ###
            $scope.titleSlug = () -> $scope.form.slug = $scope.form.title.toLowerCase().replace /[^a-zA-Z0-9]+/g, '-'

            ###
            # Form Edit
            ###
            $scope.addEditform = (song, is_scrap=false) ->

                $scope.display = 'form'
                $scope.is_edit = angular.isDefined song
                $scope.song    = song
                if is_scrap is true and song?.type
                    type = _.findWhere $scope.types, {slug : song.type}
                else
                    type = song?.type

                $scope.form    = 
                    _id          : song?.id           || $str_random 12
                    title        : song?.title        || ''
                    slug         : song?.slug         || ''
                    artist       : song?.artist?._id  || $str_random 12
                    artist_other : song?.artist_other || ''
                    chords       : song?.chords       || "[Intro]"
                    capo         : song?.capo         || 0
                    version      : song?.version      || '1'
                    type         : type?._id          || 1
                    difficulty   : song?.difficulty   || 1
                    audio        : song?.audio        || ''
                    video        : song?.video        || ''

                return

            ###
            # Cancel/Reset Form or other variables
            ###
            $scope.cancelForm = () ->
                $scope.display = 'lists'
                $scope.error   = {}
                $scope.form    = {}

                $scope.onsuccess = false
                $scope.onsubmit  = false
                $scope.onmessage = ''
                $scope.modalsong = {}

                return

            ###*
            #
            # @return submit
            ###
            $scope.submit = () ->

                data = $scope.form
                url  = $window.Routes.SubmitForm

                $scope.onsubmit = true

                $routeapi.send url, data, 'POST'
                .then ( response ) ->

                    _data = response.data
                    $scope.onsubmit = false
                    $scope.error    = {}

                    if response.status is 200
                        if _data?.errors
                            $scope.onsubmit = false
                            $scope.error    = _data.errors
                        else
                            $scope.onsuccess = true
                            $scope.onmessage = _data
                            $scope.getArtists()

                            $timeout ->
                                $scope.cancelForm()
                                $scope.getCollection()
                            , 2000

                    return

                return

            ###
            # Close Modal
            ###
            $scope.closeModal = () -> $scope.modalInstance.dismiss("cancel") if $scope.modalInstance

            ###
            # Delete Collection Modal
            ###
            $scope.delete = (song) ->

                $scope.modalsong      = song
                $scope.onsubmitdelete = false

                $scope.modalInstance = $modal.open
                    templateUrl : "MODAL_DELETE_SONG"
                    size        : 'md'
                    scope       : $scope
                    backdrop    : 'static'
                    keyboard    : false

                return

            ###
            # Scrap Modal
            ###
            $scope.scriper = () ->

                $scope.formscrap = {}

                $scope.modalInstance = $modal.open
                    templateUrl : "MODAL_SCRAPER"
                    size        : 'md'
                    scope       : $scope
                    backdrop    : 'static'
                    keyboard    : false

                return

            ###
            # Scrap Confirm
            ###
            $scope.scrapConfirm = (autoedit=false) ->

                $scope.onscrap = true
                $scope.formscrap.error    = null
                $scope.formscrap.done     = false
                $scope.formscrap.autoedit = autoedit
                $scope.formscrap.chords   = []
                $scope.formscrap.form     = {}

                url  = $window.Routes.ScrapUrl
                data = 
                    _id : $str_random 32
                    url : $scope.formscrap.url

                $routeapi.send url, data, 'POST'
                .then ( response ) -> 

                    _data = response.data

                    if response.status is 200
                        if _data?.errors
                            $timeout ->
                                $scope.formscrap.error = _data.errors?.url
                        else

                            $scope.formscrap.form = _data.form
                            $scope.formscrap.form.artist_other = $scope.formscrap.form.artist?.name if $scope.formscrap.form.artist?._id is 'others'
                            $scope.formscrap.chords =_data.chords
                            $scope.formscrap.done   = true

                            $scope.scrapContinue() if autoedit is true
                            $scope.formscrap.autoedit = false

                    
                    $scope.onscrap = false

                .catch (reason) ->
                    $scope.formscrap.error = 'Connection timed out. Please try again in a few seconds.'
                    $scope.onscrap = false

                return

            ###
            # Edit Scrap
            ###
            $scope.scrapContinue = () ->

                form = $scope.formscrap.form

                if form
                    $scope.addEditform form, true
                    $scope.formscrap = {}
                    $scope.closeModal()

                    $scope.is_edit = false

                return

            ###
            # Confirm Delete
            ###
            $scope.deleteConfirm = () ->

                $scope.onsubmitdelete = true
                url  = $window.Routes.DeleteSong
                data = 
                    _id : $scope.modalsong.id

                $routeapi.send url, data, 'POST'
                .then ( response ) -> 
                    $scope.closeModal()
                    $scope.cancelForm()
                    $scope.getCollection()
 
                return


            ###
            # Multi Scraper
            ###
            $scope.multiScraper = () ->

                $scope.scrapsongs  = {}
                $scope.scrappaging = 
                    count   : 0
                    current : 1
                    total   : 0


            $scope.saveFormScraper = (song, currentpage) ->

                song.onrequest = true

                url  = $window.Routes.ScrapUrl
                data = 
                    _id      : song._id
                    page     : currentpage
                    url      : song.href
                    autosave : 'save'

                $routeapi.send url, data, 'POST'
                .then ( response ) -> 

                    data = response.data
                    song = _.findWhere $scope.scrapsongs[data.page], { _id : data._id }
                    song.exists = true if song

                    song.onrequest = false

                .catch (reason) ->
                    song.onrequest = false

                return

            $scope.editFormScraper = (song) ->
                $scope.addEditform()
                $scope.scriper()

                $scope.formscrap.url = song.href
                $scope.scrapConfirm true

                return

            $scope.getMultiScrap = (page, reset=false) ->

                if $scope.scrapsongs[page] and reset is false
                    $scope.scrappaging.current = page
                    $scope.scrappaging.total   = 0

                else
                    $scope.loading = true

                    url  = $window.Routes.GetMultiScrap
                    url += '?search-token=' + $str_random 32
                    data = {}
                    data.page   = page if angular.isDefined page
                    data.search = $scope.scrapsearch if angular.isDefined $scope.scrapsearch

                    $routeapi.send url, data, 'POST'
                    .then ( response ) ->

                        data = response.data

                        if response.status is 200

                            $scope.scrapsongs[data.page] = data.data

                            if parseInt(data.page) is 1
                                $scope.scrappaging.count = data.paging
                            
                            $scope.scrappaging.current = data.page

                            if data.page > 1
                                songsize = _.size $scope.scrapsongs[data.page]
                                $scope.scrappaging.total = ( songsize * data.page ) - songsize

                        $scope.loading = false

                        return

                return



        new SongController()

]