###*
# systemFilter
#
# @class systemFilter
# @package AngularModules
# @author Anthony Pillos <dev.anthonypillos@gmail.com>
###


angular.module('ng-filter', [])

    .filter 'th', ->
        (number)->
            if number is 1
                return "#{number}st"
            if number is 2
                return "#{number}nd"
            if number is 3
                return "#{number}rd"
            return "#{number}th"


    ##
    #
    # @params (object)  object      Items Collections
    # @method isEmpty()
    # @return boolean
    ##
    .filter 'isEmpty', () ->
        (object) ->
            angular.equals {},object
    ##
    #
    #
    # @params (string)  items       Items Collections
    # @params (boolean) field       Field Name
    # @method groupBy()
    ##
    .filter 'groupBy', ['$parse', ($parse) ->
        _.memoize (items, field) ->
            getter = $parse(field)
            _.groupBy items, (item) ->
                getter item
    ]

    ##
    #
    #
    # @params (string)  items       Items Collections
    # @params (boolean) field       Field Name
    # @method groupBy()
    ##
    .filter 'multipleOf', ->
        (arrayLength) ->
            arrayLength = Math.ceil(arrayLength)
            arr = new Array(arrayLength)
            i = 0
            while i < arrayLength
                arr[i] = i
                i++
            arr


    ##
    # Ex. {[ '10000' | format_bytes ]}
    #
    # @params (string)  value           Strign to be trim.
    # @params (boolean) wordwise        If set to 1, it will cut by words.
    # @params (string)  max             Max Length before truncating our string
    # @params (string)  tail            Separator after the end of string default is '...'
    # @method truncate()
    ##
    .filter 'format_bytes', ->
        (bytes, si) ->
            si = 1024
            thresh = if si then 1000 else 1024
            if bytes < thresh
                return bytes + ' B'
            units = if si then ['KB','MB','GB','TB','PB','EB','ZB','YB'] else [ 'KiB', 'MiB', 'GiB', 'TiB', 'PiB', 'EiB', 'ZiB', 'YiB']
            u = -1
            loop
                bytes /= thresh
                ++u
                unless bytes >= thresh
                    break
            bytes.toFixed(1)+' '+units[u]

    ##
    # Ex. {[ 'Lorem ipsum data string' | str_limit:true:10]}
    #
    # @params (string)  value           Strign to be trim.
    # @params (boolean) wordwise        If set to 1, it will cut by words.
    # @params (string)  max             Max Length before truncating our string
    # @params (string)  tail            Separator after the end of string default is '...'
    # @method truncateStr()
    ##
    .filter 'str_limit', ->

        (value, max, wordwise, tail) ->
            if !value
              return ''
            max = parseInt(max, 10)
            if !max
              return value
            if value.length <= max
              return value
            value = value.substr(0, max)
            if wordwise
              lastspace = value.lastIndexOf(' ')
              if lastspace != -1
                value = value.substr(0, lastspace)
            value + (tail or '...')

    ##
    # Ex. {[ 'Lorem ipsum data string' | truncateMiddle]}
    #
    # @params (string)  str         Strign to be trim.
    # @params (boolean) length      Lenght of letters that will be trim off.
    # @params (string)  separator   Separator at the middle of string default is '...'
    # @method truncateMiddle()
    ##
    .filter 'truncateMiddle', ->
        (str, length = 20, separator = '...') ->
            return '' if str is null
            return '' if str is undefined
            return str if str.length <= length

            pad = Math.round (length - separator.length) / 2
            start = str.substr(0, pad)
            end = str.substr(str.length - pad)

            [start, separator, end].join('')

    ##
    # Ex. {[ 97123456789 | mobile ]}
    #
    # @params (string)  str string to be formatted
    # @method mobile()
    ##
    .filter 'mobile', ->
        (str) ->
            # ^ start \+ remove plus sign in the start of the string OR \s remove all space
            value = str.toString().trim().replace(/^\+|\s/g, '')

            country = value.slice(0, 3)
            city    = value.slice(3, 5)
            number  = value.slice(5)
            number  = number.slice(0, 3) + ' ' + number.slice(3)
            #return ('+' + country + ' ' + city + ' ' + number).trim()
            mobile = (country + ' ' + city + ' ' + number).trim()
            mobile = if mobile isnt '' then '+'+mobile
            return mobile

    ##
    # Ex. {[ 97123456789 | landline ]}
    #
    # @params (string)  str string to be formatted
    # @method landline()
    ##
    .filter 'landline', ->
        (str) ->
            # ^ start \+ remove plus sign in the start of the string OR \s remove all space
            value = str.toString().trim().replace(/^\+|\s/g, '')

            country = value.slice(0, 3)
            city    = value.slice(3, 4)
            number  = value.slice(4)
            number  = number.slice(0, 3) + ' ' + number.slice(3)
            return ('+' + country + ' ' + city + ' ' + number).trim()

    ##
    # Ex. {[ 97123456789 | currency ]}
    #
    # @params (string)  str string to be formatted
    # @method mobile()
    ##
    .filter 'priceCurrency', ['$window', ($window) ->
        (str, currency) ->
            str = 0 if not str
            if angular.isUndefined currency
                currency = $window.PrintArabia.Vars.Currency || '$'

            if $window.Vars?.CurrencyPosition? and $window.Vars.CurrencyPosition is true
                return String currency + str

            return str + String currency
    ]


    ##
    # Ex. {[ 97123456789 | currency ]}
    #
    # @params (string)  str string to be formatted
    # @method mobile()
    ##
    .filter 'mmToCm', ->
        (mm, decimalPoint) ->
            x = 0
            if angular.isUndefined decimalPoint
                decimalPoint = 2
                
            if _.isNumber(mm)
              x = _h.numberFormat( (mm * 0.1) , decimalPoint)
              remainder = x % 1
              if remainder is 0
                x = Math.ceil(x)
              else
                y = x.toString().substr(-1,1)
                x = x.toString().substring(0, x.toString().length-1) if y is "0"
            x

    ##
    # Ex. {[ "<strong>Render Bold Text</strong>" | trusted_html ]}
    #
    # @params (string)  text string Render as html
    # @method mobile()
    ##
    .filter 'trusted_html', ['$sce', ($sce) ->
        (text) ->
            $sce.trustAsHtml(text)
    ]

    .filter 'toDateFormat', ->
        (dateString, format) ->
            if angular.isUndefined format
                # format = 'MMM.DD.YYYY HH:mm' # format for date
                # if format is not specified set to default format
                format = 'YYYY-MM-DD HH:mm:ss'
            moment(dateString).format(format)

    .filter 'dateTimeFormat', ['$filter', ($filter) -> 
        (dateString, format) ->
            if angular.isUndefined format
                format = 'YYYY-MM-DD'

            a = dateString.split(/[^0-9]/) # work around for safari
            # return $filter('date')(new Date(dateString), format); 
            return $filter('date')(new Date(a[0],a[1]-1,a[2],a[3],a[4],a[5]), format); 
    ]

    ##
    # Difficulty Label
    #
    # @params (string) text string Render as html
    # @method mobile()
    ##
    .filter 'difficulty', [ () ->
        (num) ->
            diff  = parseInt num
            label = 'Novice'
            if diff is 2
                label = 'Intermediate'
            else if diff is 3
                label = 'Advanced'

            return label
    ]
